%{ 
    Script develovep to obtain the CCO coastal profile data of North Norfolk 
    and calculate the annual recession rate (rec) and the beach wegde area
    (BWA) using the detrended method to obtain the top and toe cliff and
    calculating the BWA using the area below the curve. After that the
    decadal scale relationship and the probability distribution between
    BWA and rec are calculated.

    This script was completed on November 21, 2019 (by P.M.L. Granada)
%}

%% 1. We extract those profiles that contain the Reg_ID identifiers we are
% 	  interested in and add the corresponding date.

close all;clc, clear

% Names of the unprotected location used (same as in the previous work
% (Lee, 2008))
prfID = {'3b00046','3b00065','3b00087','3b00107','3b00194','3b00214',...
    '3b00234','3b00357','3b00378'};

% Loading .txt data
G = dir('*.txt');
G = struct2cell(G);
G = G(1,:)';
DAT = [];
TEX = [];

% We go through all the files comparing the Reg_IDs and filling in the 
% variables for numeric data and for text data.
for ii = 1:length(G)
    
    fprintf('Processing file %d of %d - %s\n',ii,length(G),G{ii})
    fid = fopen(G{ii}); 
    prf = textscan(fid,'%f %f %f %f %s %s %s',...
    'Delimiter','\t','CollectOutput',1,'Headerlines',1);
    II = zeros(size(prf{1,2},1),length(prfID));
    STR = (prf{1,2}(:,3));
    
    for jj = 1:length(prfID)
        
        I = (strcmp(STR,prfID{jj}));
        II(:,jj) = I;
    end
    
    II = sum(II,2); 
    if sum(II) > 0
        II = logical(II);
        DAT = [DAT; [(prf{1,1}(II,:)) datenum(repmat({G{ii}(10:17)},...
            sum(II),1), 'yyyymmdd')]];
        TEX = [TEX; [prf{1,2}(II,:) repmat({G{ii}(10:17)},sum(II),1)]];
    end
    fclose(fid);   
end

% We save all the files we are interested in according to their type (data
% or text), in .mat format, separated by their identifiers

for jj = 1:length(prfID)
    
    fprintf('Saving file %d of %d - %s\n',jj,length(prfID),prfID{jj})
    I = (strcmp(TEX(:,3),prfID{jj}));
    dat = DAT(I,:);
    tex = TEX(I,:);
    save([prfID{jj},'.mat'],'dat','tex')
    
end

%% 2. Plotting all the profiles of a selected location in the same Figure

clear, clc

load 3b00046

figure(100)
hold on
grid on
colorbar('Ticks',[0.02,0.248,0.515,0.75,0.9809],'TickLabels',{'1993',...
    '1999','2006','2012','2018'})
xlabel('Chainage (m)')
ylabel('Elevation (m)')

% To plot by date we get only one value per profile
yr = unique(tex(:,4));
clr = colormap(jet(length(yr)));

% We make a loop to represent all the profiles in the same Figure
for ii = 1 : length(yr)
    
    I = (strcmp(tex(:,4),yr{ii}));
    plot(dat(I,4),dat(I,3),'Color',clr(ii,:))
    drawnow
    
end

%% 3. Script to screen the profiles that are duplicated

close all; clear, clc

G = dir('3b00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id); 
    
    yr = unique(dat(:,5));
    DAT = [];
    TEX = [];
    % We use the date and the chainage to screen the duplicated
    for ii = 1 : length(yr)

        i0 = find(dat(:,5) == yr(ii));
        x = dat(i0,4);
        [~, ia, ic] = unique(x);
        DAT = [DAT; dat(i0(ia),:)];
        TEX = [TEX; tex(i0(ia),:)];

    end

    dat = DAT;
    tex = TEX;
    
    fprintf('File %d of %d screened - %s\n',jj,length(G),G{jj}(1:7))
    save(id,'dat','tex')
end

%% 4. Script to extract winter to winter profiles. Here we also exclude
%    the data taken in close months.

clear,clc

G = dir('3b00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id);
    
    DAT = [];
    TEX = [];
    DIF = [];
    
    a = tex(:,4);
    
    for ii = 1 : length(a)
        
        wint = str2double(a{ii}(5:6));  % To be profiles taken in the same date
        
        if wint < 4           
            DAT = [DAT; dat(ii,:)];
            TEX = [TEX; tex(ii,:)];
        end
    end
    
    yr = unique(DAT(:,5));
    
    for nn = 2: length(yr)
        
        dif = yr(nn) - yr(nn-1);
        DIF = [DIF; dif];
        
    end
    
    % If the difference between data is less than 100 days we don't take
    % the profile because is taken in the same year, on a close date
    for n = 2 : length(yr)
               
        if DIF(n-1) < 100            
            yr(n) = NaN;           
        end
    end
    
    DAT2 = [];
    TEX2 = [];
    
    for nn = 1: length(yr)        
       for i = 1 : length(DAT(:,1)) 
           % If the date is close to the previous one (yr = NaN) and it is
           % not copy en the new list
           if DAT(i,5) == yr(nn)
               
               DAT2 = [DAT2; DAT(i,:)];
               TEX2 = [TEX2; TEX(i,:)];
           end
       end
    end
    
    dat = DAT2;
    tex = TEX2;

    fprintf('Saving new file %d of %d - %s\n',jj,length(G),G{jj}(1:7))
    save(['Winter', id],'dat','tex')     
end

%% 5.1 Script to extract the cliff top using the detrended method and
%  calculate the recession rate for all the profiles.
%  5.2 Script to extract the cliff toe using the detrended method and
%  calculate the BWA for all the profiles, using the method that involve
%  get the first local min in the detrend or the following one if the BWA
%  is below a maximum value (bwa_max).
%  The two scripts could be joined to avoid the repetition of some loops.

clear,clc

prfID = dir('Winter*');
prfID = struct2cell(prfID);
prfID = prfID(1,:)';

% We create mhws data based on the values obtain from 2017 database of DEFRA
mhws = [2.48,2.48,2.45,2.45,2.38,2.34,2.34,2.19,2.19];
% BWA_max based on Lee's results
bwa_max = 80.0; 

% Variables that we are going to save:
ALLdata = [];
ALLnames = [];
MEAN = [];
rec_tot = [];

for jj = 1:length(prfID)
    
    id = prfID{jj};
    load(id);   

    yr = unique(dat(:,5));

    % We make a loop to obtain the minimum value that is risen for all the 
    % profiles. In this way we avoid problems with long profiles
    p1 = dat(dat(:,5) == yr(1),4);
    cmin = p1(end);
    for ii = 2 : length(yr)-1

        p0 = dat(dat(:,5) == yr(ii),4);
        p1 = dat(dat(:,5) == yr(ii+1),4);
        cmin = min([p0(end);p1(end);cmin]); 
        
    end
    
    % We interpolate fixing cmin and changing te first point of the 
    % corresponding profile. Then we established the detrending and
    % calculate the top for each profile
    
    % 5.1. RECESSION RATE
    
    TOP_X = [];
    TOP_Z = [];

    for ii = 1 : length(yr)

        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);
        x_interp = x(1):0.01:cmin;
        z_interp = interp1(x,z,x_interp,'linear');

        % Detrending
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1-z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);

        % We calculate the max that correspond to the top and we use the
        % interpolate points to obtain it. For be rigorous, we should 
        % search the values of the profiles that correspond to those points,
        % but it's not neccesary because the interpolation is very accurate 
        % (+/- 0.01)

        toe_z = z_interp(find(min(z_detrend)==z_detrend,1));
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        
        % Below we repeat the detrended method for calculating the top with
        % more accuracy using the previous top as initial limit
        
        x_interp_top2 = top_x:0.001:cmin;
        z_interp_top2 = interp1(x,z,x_interp_top2,'linear');    
        z0 = z_interp_top2(end);
        z1 = z_interp_top2(1);
        x0 = x_interp_top2(end);
        x1 = x_interp_top2(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend_top2 = z_interp_top2 - (a*x_interp_top2);
        
        pos_toe = find(z_interp_top2 <= toe_z,1);
        top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
        top_z = z_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
        
        % Condition for the profiles that are incomplete
        if top_z < 3
            top_z = NaN;
            top_x = NaN;
        end
        
        TOP_X = [TOP_X; top_x];
        TOP_Z = [TOP_Z; top_z];
    end
    top_xz = [TOP_X,TOP_Z];
    
    % We calculate the recession rate
    rec = zeros([length(top_xz) 1]);
    rec(1) = 0.0;
    for ii = 2:length(top_xz)
        if top_xz(ii,1)*top_xz(ii-1,1) <= 0
            rec(ii) = abs(top_xz(ii,1)) + abs(top_xz(ii-1,1));
        else
            rec(ii) = abs(abs(top_xz(ii,1)) - abs(top_xz(ii-1,1)));
        end    
    end
    
    % 5.2 BEACH WEDGE AREA
    
    BWA = [];

    for ii = 1 : length(yr)
        
        % First we calculate top and toe cliff for each profile as earlier
        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);

        x_interp = x(1):0.01:cmin;
        z_interp = interp1(x,z,x_interp,'linear');
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);
        
        % We calculate the top
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        
        % We interpolate again and repeat the detrending
        x_interp_top = top_x:0.01:cmin;
        z_interp_top = interp1(x,z,x_interp_top,'linear');
        z0 = z_interp_top(end);
        z1 = z_interp_top(1);
        x0 = x_interp_top(end);
        x1 = x_interp_top(1);
        a = (z1-z0)/(x1-x0);
        z_detrend_top = z_interp_top - (a*x_interp_top);
        
        TF = islocalmin(z_detrend_top);
%         % Script lines for check the methodology
%         figure(81)
%         plot(x_interp_top,z_detrend_top,'g', x_interp_top(TF),...
%              z_detrend_top(TF),'r*')
%         hold on; grid on
%         plot(x_interp_top,z_interp_top,'b')
        toe_x = x_interp_top(TF);
        toe_z = z_interp_top(TF);
        
        % To extract the first minimun
        if length(toe_x) > 1
            toe_x = toe_x(1);
            toe_z = toe_z(1);
        end
        % We only use top_z position to ckeck if the profile is complete
        top_z = z_interp(find(max(z_detrend)==z_detrend,1));
        if top_z < 3
            toe_x = NaN;
        end
            
        % First calculation of BWA
        xz_cut = find(z_interp >= mhws(jj),1,'last');
        xz_toe = find(x_interp >= toe_x,1,'first');
        z_interp = z_interp - mhws(jj);
        bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
        
        % Because there may be some profiles that don't cut the mhws due to
        % cmin we use the next condition
        if cmin < x_interp(xz_cut)           
            x_interp_end = x(1):0.01:x(end);
            z_interp_end = interp1(x,z,x_interp_end,'linear');
            xz_cut_end = find(z_interp_end >= mhws(jj),1,'last');
            z_interp_end = z_interp_end - mhws(jj);
            xz_toe_end = find(x_interp_end >= toe_x,1,'first');
            bwa = trapz(x_interp_end(xz_toe_end:xz_cut_end),z_interp_end(xz_toe_end:xz_cut_end));
        end
        
        % Condition for profile (3b00378 97-98) where there are two MHWS 
        % cuts and the x_toe is after the x_cut, respectively     
        if bwa < 0
            bwa = 0;
        end
        
        % We check if we have a toe. If we don't then bwa = NaN. This can
        % happen when the profile is incomplete       
        if isempty(xz_toe) == 1
            bwa = NaN;
        end
        % If the bwa obtained is bigger that bwa_max we repeated the
        % calculation of the toe, as the second local minimun        
        if bwa > bwa_max
            
            toe_x = x_interp_top(TF);
            toe_z = z_interp_top(TF);
            
            if length(toe_x) > 1  % Condition to extract the second min
                
                toe_x = toe_x(2);
                toe_z = toe_z(2);               
                % BWA second calculation
                xz_toe = find(x_interp >= toe_x,1,'first');
                bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
                
            end
            
            % BWA calculation if bwa > bwa_max still
            if bwa > bwa_max
                
                toe_x = x_interp_top(TF);
                toe_z = z_interp_top(TF);
                % Condition to extract the third min and calculate BWA again
                if length(toe_x) > 2
                    toe_x = toe_x(3);
                    toe_z = toe_z(3);
                    xz_toe = find(x_interp >= toe_x,1,'first');
                    bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
                end
                % BWA calculation if bwa > bwa_max still still
                if bwa > bwa_max
                    
                    toe_x = x_interp_top(TF);
                    toe_z = z_interp_top(TF);
                    % Condition to extract the third min and calculate BWA again
                    if length(toe_x) > 3
                        toe_x = toe_x(4);
                        toe_z = toe_z(4);
                        xz_toe = find(x_interp >= toe_x,1,'first');
                        bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
                    end                                       
                end               
            end
        end
        BWA = [BWA; bwa];
        
    end
    
    BWA_mean = [];
    BWA_mean = [BWA_mean; BWA(1)];
    for k = 1:length(BWA)-1
        
        if isnan(BWA(k))
            BWA_mean = [BWA_mean; BWA(k)];
        else
            BWA_mean = [BWA_mean; nanmean([BWA(k),BWA(k+1)])];
        end    
    end
    
    % We save all the BWA, REC in one unique table, with the corresponding 
    % date and we use another table for save the corresponding survey unit.
    % In this way, later it will be easier to find outliers
    date = str2num(datestr(yr,'yyyy'));
    unit = tex(1,3);
        
    % We calculate the mean value for each monitoring site before populate 
    % with Nan
    Allmean = [mean(BWA,'omitnan') mean(rec,'omitnan')];    
    MEAN = [MEAN; Allmean];
    
    % We calculate the total recession for the 24 years
    rec_tot = [rec_tot; sum(rec,'omitnan')];
    
    % We create a time vector for populate with the NaN the missing years
    vt = 1993:1:2018;   
    for n=1:length(vt)
        
        idata = find(date==vt(n));
        
        if isempty(idata)
            dumOurs = NaN(1,3);
            dumOurs(1,1) = vt(n);
        else
            dumOurs = [date(idata) BWA_mean(idata) rec(idata)];
        end
        
        Alldata(n,:) = dumOurs;
        Allnames(n,:) = unit{1};
    end
    
    ALLdata = [ALLdata; Alldata];
    ALLnames = [ALLnames; Allnames];   
end
        
% We save all the results in a .mat file
save(['NN_winter_ALL_REC_BWA','.mat'],'ALLdata','ALLnames','MEAN','rec_tot')
fprintf(' NN_winter_ALL_REC_BWA calculated and saved ')

%% 06. Script to plot REC and BWA per year

clear,clc

load('NN_winter_ALL_REC_BWA.mat')

red = 1/255*[235,6,3];
blue = 1/255*[2,6,200];

% First we eliminate the year 1993, because we can't calculate BWA and
% recession rate without the 1992 data
i1993 = find(ALLdata(:,1)==1993);
ALLdata(i1993,2) = NaN;
ALLdata(i1993,3) = NaN;

% To plot by profile
ALLnames = string(ALLnames);
unit = unique(ALLnames);

for ii = 1 : length(unit)
    
    I = (strcmp(ALLnames,unit{ii}));
    
    fig = figure(ii);
    left_color = red;
    right_color = blue;
    set(fig,'defaultAxesColorOrder',[left_color; right_color]);
    hold on
    grid on
    yyaxis right
    set(gca,'FontName','times','FontSize',10)
    ylabel('Recession rate ($m/yr$)','Interpreter','LaTeX','FontSize',13)
    plot(ALLdata(I,1),ALLdata(I,3),'Color',blue)
    plot(ALLdata(I,1),ALLdata(I,3),'s','MarkerEdgeColor',blue,'MarkerFaceColor',blue)
    drawnow
    
    yyaxis left
    set(gca,'FontName','times','FontSize',10)
    ylabel('BWA ($m^{2}$)','Interpreter','LaTeX','FontSize',13)
    xlabel('Years','Interpreter','LaTeX','FontSize',13)
    text(2012, max(ALLdata(I,2)), unit{ii},'FontSize',15)
    plot(ALLdata(I,1),ALLdata(I,2),'--','Color',red)
    plot(ALLdata(I,1),ALLdata(I,2),'d','MarkerEdgeColor',red,'MarkerFaceColor',red)
    xlim([1993.5 2018.5])
    drawnow      
    
end

%% 07. Script to plot the decadal scale relationship for all and by profile

close all; clear,clc

load('NN_winter_ALL_REC_BWA')

% Plotting all decadal scale relationship
figure(81)
hold on
grid on
title('Decadal Scale Relationship YEARLY data individual SDMS')
xlabel('BWA (m^2)')
ylabel('Recession rate (m/year)')
set(gca,'FontName','times','FontSize',16)
plot(ALLdata(:,2),ALLdata(:,3),'ok')

figure(82)
hold on
grid on
title('Decadal Scale Relationship MEAN value individual SDMS')
xlabel('BWA (m^2)')
ylabel('Recession rate (m/year)')
set(gca,'FontName','times','FontSize',16)
plot(MEAN(:,1),MEAN(:,2),'ok')

% Plotting by profile
ALLnames = string(ALLnames);
unit = unique(ALLnames);

for ii = 1 : length(unit)
    
    I = (strcmp(ALLnames,unit{ii}));
    
    figure(ii+40)
    hold on
    grid on    
    xlabel('BWA (m^2)')
    ylabel('Recession rate (m/year)')
    set(gca,'FontName','times','FontSize',16)
    plot(ALLdata(I,2),ALLdata(I,3),'ok')
    text(max(ALLdata(I,2))-5, max(ALLdata(I,3)), unit{ii},'FontSize',15)
    drawnow
    
end

%% 8.  Probability distributions

close all;clear,clc

load('NN_winter_ALL_REC_BWA')
green = 1/255*[3,188,33];

% We separate into different BWA ranges
lim1 = 21;
lim2 = 52;

zone1 = [];
zone2 = [];
zone3 = [];

for ii = 1:length(ALLdata(:,2))
   
    if ALLdata(ii,2) < lim1        
        zone1 = [zone1; ALLdata(ii,2) ALLdata(ii,3)];     
    elseif ALLdata(ii,2) > lim1 && ALLdata(ii,2) < lim2
        zone2 = [zone2; ALLdata(ii,2) ALLdata(ii,3)];    
    else
        zone3 = [zone3; ALLdata(ii,2) ALLdata(ii,3)];      
    end
    
end

% We count the data that are found in intervals of 1 m/yr of the recession 
% rate and plot for all the data and the different zones:

% All data
lim_max = floor(max(ALLdata(:,3)))+1;
x = 0:1:lim_max;  % Here we can change the range of the intervals
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(ALLdata(:,3))
               
        if ALLdata(j,3) > x(jj) && ALLdata(j,3) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end 
end

prob = prob/sum(prob);

figure(83)
hold on
grid on
title('ALL')
bar(x,prob,'FaceColor', green)
xlabel('Recession (m/yr)')
ylabel('Probability')
set(gca,'FontName','times','FontSize',16)
xlim([-0.5 22.5])
ylim([0 1])

% ZONE 1   BWA > 21 m^2
x = 0:1:lim_max;
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone1(:,2))
               
        if zone1(j,2) > x(jj) && zone1(j,2) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end    
end

prob = prob/sum(prob);

figure(99)
subplot(3,2,1)
hold on
grid on
bar(x,prob,'FaceColor', green)
set(gca,'FontName','times','FontSize',16)
title({'\bf North Norfolk cliffs'; '\bf BWA \boldmath$< \: 21 \: m^{2}$'},'Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',20)
xlim([-0.5 22.5])
ylim([0 1])

% ZONE 2   BWA 21 - 52 m^2
x = 0:1:lim_max;
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone2(:,2))
               
        if zone2(j,2) > x(jj) && zone2(j,2) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end    
end

prob = prob/sum(prob);

figure(99)
subplot(3,2,3)
hold on
grid on
bar(x,prob,'FaceColor', green)
set(gca,'FontName','times','FontSize',16)
title('\bf BWA 21 - 52 \boldmath$m^2$','Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',20)
xlim([-0.5 22.5])
ylim([0 1])

% ZONE 3   BWA > 52 m^2
x = 0:1:lim_max;
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone3(:,2))
               
        if zone3(j,2) > x(jj) && zone3(j,2) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end   
end
prob = prob/sum(prob);

figure(99)
subplot(3,2,5)
hold on
grid on
bar(x,prob,'FaceColor', green)
set(gca,'FontName','times','FontSize',16)
title('\bf BWA \boldmath$> \: 52 \: m^{2}$','Interpreter','LaTeX')
xlabel('Recession rate $(m/yr)$','Interpreter','LaTeX','FontSize',20)
ylabel('Probability','Interpreter','LaTeX','FontSize',20)
xlim([-0.5 22.5])
ylim([0 1])

% % To find outliers:
%  ALLdata(find(ALLdata(:,3)==zone3(66,2)),1)
%  ALLnames = string(ALLnames);
%  ALLnames(find(ALLdata(:,3)==zone3(66,2)),1)

% The end
