%{ 
    Script develovep to obtain the CCO coastal profile data of North Norfolk and
    calculate the annual recession rate (rec) and the beach wegde area (BWA)
    using the detrended method to obtain the top and toe cliff and
    calculating the BWA using the area below the curve. After that the
    decadal scale relationship and the probability distribution between
    BWA and rec are calculated. In the script we also repeat the analysis
    for the previous work results (Lee 2008) for validated the methodology.

    This script was completed on October 25, 2019 (by P.M.L. Granada)
%}

%% 1. We extract those profiles that contain the Reg_ID identifiers we are
% 	  interested in and add the corresponding date.

clc, clear
close all

% Names of the unprotected location used in the previous work (Lee, 2008)
prfID = {'3b00046','3b00065','3b00087','3b00107','3b00194','3b00214',...
    '3b00234','3b00357','3b00378'};

% Loading .txt data
G = dir('*.txt');
G = struct2cell(G);
G = G(1,:)';
DAT = [];
TEX = [];

% We go through all the files comparing the Reg_IDs and filling in the 
% variables for numeric data and for text data.
for ii = 1:length(G)
    
    fprintf('Processing file %d of %d - %s\n',ii,length(G),G{ii})
    fid = fopen(G{ii}); 
    prf = textscan(fid,'%f %f %f %f %s %s %s',...
    'Delimiter','\t','CollectOutput',1,'Headerlines',1);
    II = zeros(size(prf{1,2},1),length(prfID));
    STR = (prf{1,2}(:,3));
    
    for jj = 1:length(prfID)
        
        I = (strcmp(STR,prfID{jj}));
        II(:,jj) = I;
    end
    
    II = sum(II,2); 
    if sum(II) > 0
        II = logical(II);
        DAT = [DAT; [(prf{1,1}(II,:)) datenum(repmat({G{ii}(10:17)},...
            sum(II),1), 'yyyymmdd')]];
        TEX = [TEX; [prf{1,2}(II,:) repmat({G{ii}(10:17)},sum(II),1)]];
    end
    fclose(fid);   
end

% We save all the files we are interested in according to their type (data
% or text), in .mat format, separated by their identifiers

for jj = 1:length(prfID)
    
    fprintf('Saving file %d of %d - %s\n',jj,length(prfID),prfID{jj})
    I = (strcmp(TEX(:,3),prfID{jj}));
    dat = DAT(I,:);
    tex = TEX(I,:);
    save([prfID{jj},'.mat'],'dat','tex')
    
end

%% 2. Plotting all the profiles of a selected location in the same Figure

clear, clc

load 3b00046

figure(113)
hold on
grid on
colorbar('Ticks',[0.02,0.248,0.515,0.75,0.9809],'TickLabels',{'1993',...
    '1999','2006','2012','2018'})
xlabel('Chainage (m)')
ylabel('Elevation (m)')

% To plot by date we get only one value per profile
yr = unique(tex(:,4));
clr = colormap(jet(length(yr)));

% We make a loop to represent all the profiles in the same Figure
for ii = 1 : length(yr)
    
    I = (strcmp(tex(:,4),yr{ii}));
    plot(dat(I,4),dat(I,3),'Color',clr(ii,:))
    drawnow
    
end

%% 3. Script to screen the profiles that are duplicated

close all
clear, clc

G = dir('3b00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id); 
    
    yr = unique(dat(:,5));

    DAT = [];
    TEX = [];
    % We use the date and the chainage to screen the duplicated
    for ii = 1 : length(yr)

        i0 = find(dat(:,5) == yr(ii));
        x = dat(i0,4);
        [~, ia, ic] = unique(x);

        DAT = [DAT; dat(i0(ia),:)];
        TEX = [TEX; tex(i0(ia),:)];

    end

    dat = DAT;
    tex = TEX;
    
    fprintf('File %d of %d screened - %s\n',jj,length(G),G{jj}(1:7))
    save(id,'dat','tex')
end

%% 4. We extract Lee profiles, winter profiles and the year after 2003

clear, clc

G = dir('3b00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id);

    DAT = [];
    TEX = [];
    a = tex(:,4);

    for ii = 1 : length(a)

        b = str2double(a{ii}(5:6));  % To be the winter profile
        c = str2double(a{ii}(1:4));  % To be the year use by Lee

        if (b < 5) && (c < 2004)
            DAT = [DAT; dat(ii,:)];
            TEX = [TEX; tex(ii,:)];   
        end
    end
    
    dat = DAT;
    tex = TEX;
    
    fprintf('Saving new file %d of %d - %s\n',jj,length(G),G{jj}(1:7))
    save(['Lee', id],'dat','tex')
    
end

%% 5.1 Script to extract the cliff top using the detrended method and
%  calculate the recession rate for all the profiles.
%  5.2 Script to extract the cliff toe using the detrended method and
%  calculate the BWA for all the profiles, using the method that involve
%  get the first local min in the detrend or the following if the BWA is
%  below a maximum value (bwa_max).
%  The two scripts could be joined to avoid the repetition of some loops.

clear,clc

% Names of the Reg_IDs that Lee used, the unprotected sites
prfID = {'Lee3b00046','Lee3b00065','Lee3b00087','Lee3b00107',...
    'Lee3b00194','Lee3b00214','Lee3b00234','Lee3b00357','Lee3b00378'};

% To load the results obtained from the graphics supply in Lee's article
J = dir('*_bwa_rec.mat');
J = struct2cell(J);
J = J(1,:)';

% We create one MHWS value based on two of the three values that Lee suplied
mhws = [2.45;2.45;2.45;2.45;2.45;2.45;2.45;2.45;2.45];
% mhws = [2.48,2.48,2.45,2.45,2.38,2.34,2.34,2.19,2.19]; % Updated values

bwa_max = 80.0; % BWA_max based on Lee's results.

% Variables that we are going to save:
ALLdata = [];
ALLnames = [];
MEAN = [];
rec_tot = [];

for jj = 1:length(prfID)
    
    id = prfID{jj};
    load(id);   

    yr = unique(dat(:,5));

    % We make a loop to obtain the minimum value that is risen for all the 
    % profiles. In this way we avoid problems with long profiles
    p1 = dat(dat(:,5) == yr(1),4);
    cmin = p1(end);
    for ii = 2 : length(yr)-1

        p0 = dat(dat(:,5) == yr(ii),4);
        p1 = dat(dat(:,5) == yr(ii+1),4);
        cmin = min([p0(end);p1(end);cmin]); 
        
    end
    
    % We interpolate fixing cmin and changing te first point of the 
    % corresponding profile. Then we established the detrending and
    % calculate the top for each profile
    
    % 5.1. RECESSION RATE
    
    TOP_X = [];
    TOP_Z = [];

    for ii = 1 : length(yr)

        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);

        x_interp = x(1):0.01:cmin;
        z_interp = interp1(x,z,x_interp,'linear');

        % Detrending
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1-z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);

        % We calculate the max that correspond to the top and we use the
        % interpolate points to obtain it. For be rigorous, we should 
        % search the values of the profiles that correspond to those points,
        % but it's not neccesary because the interpolation is very accurate 
        % (+/- 0.01), that it's the error of the field data

        toe_z = z_interp(find(min(z_detrend)==z_detrend,1));
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        
        % Below we repeat the detrended method for calculating the top with
        % more accuracy using the previous top as initial limit
        
        x_interp_top2 = top_x:0.001:cmin;
        z_interp_top2 = interp1(x,z,x_interp_top2,'linear');    
        z0 = z_interp_top2(end);
        z1 = z_interp_top2(1);
        x0 = x_interp_top2(end);
        x1 = x_interp_top2(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend_top2 = z_interp_top2 - (a*x_interp_top2);
        
        pos_toe = find(z_interp_top2 <= toe_z,1);
        top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
        top_z = z_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
        
        % Condition for the profiles that are incomplete
        if top_z < 3
            top_z = NaN;
            top_x = NaN;
        end
        
        TOP_X = [TOP_X; top_x];
        TOP_Z = [TOP_Z; top_z];

    end
    top_xz = [TOP_X,TOP_Z];
    
    % We calculate the recession rate
    rec = zeros([length(top_xz) 1]);
    rec(1) = 0.0;
    for ii = 2:length(top_xz)
        if top_xz(ii,1)*top_xz(ii-1,1) <= 0
            rec(ii) = abs(top_xz(ii,1)) + abs(top_xz(ii-1,1));
        else
            rec(ii) = abs(abs(top_xz(ii,1)) - abs(top_xz(ii-1,1)));
        end    
    end
    
    % 5.2 BEACH WEDGE AREA
    
    BWA = [];

    for ii = 1 : length(yr)
        
        % First we calculate top and toe cliff for each profile as earlier
        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);

        x_interp = x(1):0.01:cmin;
        z_interp = interp1(x,z,x_interp,'linear');
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);
        
        % We calculate the top
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        
        % We interpolate again and repeat the detrending
        x_interp_top = top_x:0.01:cmin;
        z_interp_top = interp1(x,z,x_interp_top,'linear');
        z0 = z_interp_top(end);
        z1 = z_interp_top(1);
        x0 = x_interp_top(end);
        x1 = x_interp_top(1);
        a = (z1-z0)/(x1-x0);
        z_detrend_top = z_interp_top - (a*x_interp_top);
        
        TF = islocalmin(z_detrend_top);
    %     figure(ii)
    %     plot(x_interp_top,z_detrend_top,'g', x_interp_top(TF),z_detrend_top(TF),'r*')

        toe_x = x_interp_top(TF);
        toe_z = z_interp_top(TF);
        
        % To extract the first minimun
        if length(toe_x) > 1
            toe_x = toe_x(1);
            toe_z = toe_z(1);
        end
        % Here we only use top_z position to ckeck if the profile is
        % complete
        top_z = z_interp(find(max(z_detrend)==z_detrend,1));
        if top_z < 3
            toe_x = NaN;
        end
            
        % First calculation of BWA
        xz_cut = find(z_interp >= mhws(jj),1,'last');
        z_interp = z_interp - mhws(jj);
        xz_toe = find(x_interp >= toe_x,1,'first');
        bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
        
        % Because there may be some profiles that don't cut the mhws due to
        % cmin we use the next condition
        if cmin < x_interp(xz_cut)
            
            x_interp_end = x(1):0.01:x(end);
            z_interp_end = interp1(x,z,x_interp_end,'linear');
            xz_cut = find(z_interp_end >= mhws(jj),1,'last');
            z_interp_end = z_interp_end - mhws(jj);
            xz_toe = find(x_interp_end >= toe_x,1,'first');
            bwa = trapz(x_interp_end(xz_toe:xz_cut),z_interp_end(xz_toe:xz_cut));
        end
        
        % We check if we have a toe. If we don't then bwa = NaN. This can
        % happen when the profile is not complete       
        if isempty(xz_toe) == 1
            bwa = NaN;
        end
        % If the bwa obtained is bigger that bwa_max we repeated the
        % calculation of the toe, as the second local minimun        
        if bwa > bwa_max
            
            toe_x = x_interp_top(TF);
            toe_z = z_interp_top(TF);
            
            if length(toe_x) > 1  % Condition to extract the second min
                
                toe_x = toe_x(2);
                toe_z = toe_z(2);               
                % BWA second calculation
                xz_toe = find(x_interp >= toe_x,1,'first');
                bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
                
            end
            
            % BWA calculation if bwa > bwa_max still
            if bwa > bwa_max
                
                toe_x = x_interp_top(TF);
                toe_z = z_interp_top(TF);
                % Condition to extract the third min and calculate BWA again
                if length(toe_x) > 2
                    toe_x = toe_x(3);
                    toe_z = toe_z(3);
                    xz_toe = find(x_interp >= toe_x,1,'first');
                    bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
                end              
            end
        end
        BWA = [BWA; bwa];
        
    end
    
    % We save all the BWA, REC in one unique table, with the corresponding 
    % date and we use another table for save the corresponding survey unit.
    % In this way, later it will be easier to find outliers
    date = str2num(datestr(yr,'yyyy'));
    unit = tex(1,3);
    
    % We load the results of Lee because we are going to save all together
    load(J{jj});
    Lee = eval(J{jj}(1:(end-4)));
    
    % Here we calculate the mean value of BWA using the same year of REC    
    BWA_mean = [];
    BWA_mean = [BWA_mean; BWA(1)];
    for k = 1:length(BWA)-1
        
        if isnan(BWA(k))
            BWA_mean = [BWA_mean; BWA(k)];
        else
            BWA_mean = [BWA_mean; nanmean([BWA(k),BWA(k+1)])];
        end    
    end
    
    % We calculate the mean value for each monitoring site before populate 
    % with Nan
    Allmean = [mean(BWA,'omitnan') mean(rec,'omitnan') mean(Lee(:,2)) mean(Lee(:,3))];
    MEAN = [MEAN; Allmean];
    
    % We calculate the total recession for the 10 years
    rec_tot = [rec_tot; sum(rec,'omitnan')];
    
    % We create unique time vector and populate with NaN missing years
    vt = unique([date; Lee(:,1)]);
    for n=1:length(vt)
        
        iOurs = find(date==vt(n));
        iLee = find(Lee(:,1)==vt(n));
        
        if isempty(iOurs)
            dumOurs = NaN(1,3);
            dumOurs(1,1) = vt(n);
        else
            dumOurs = [date(iOurs) BWA_mean(iOurs) rec(iOurs)];
        end
        
        if isempty(iLee)
            dumLee = NaN(1,3);
        else
            dumLee = Lee(iLee,:);
        end
        
        AllData(n,:) = [dumOurs dumLee];
        Allnames(n,:) = unit{1};
    end
    
    ALLdata = [ALLdata; AllData];
    ALLnames = [ALLnames; Allnames];
    
end

dif_bwa = ALLdata(:,2)- ALLdata(:,5);
dif_rec = ALLdata(:,3)- ALLdata(:,6);

% We save all the results in a .mat file
save(['NN_Lee_ALL_REC_BWA', '.mat'],'ALLdata','ALLnames','MEAN','rec_tot','dif_bwa','dif_rec')
fprintf(' NN_Lee_ALL_REC_BWA calculated and saved ')

%% 06 Plotting REC and BWA per year

clear,clc

load('NN_Lee_ALL_REC_BWA.mat')

red = 1/255*[235,6,3];
blue = 1/255*[2,6,200];

% To plot by profile
ALLnames = string(ALLnames);
unit = unique(ALLnames);

% We make a loop to represent all the profiles in the same figure
for ii = 1 : length(unit)
    
    I = (strcmp(ALLnames,unit{ii}));
    
    fig = figure(ii);
    left_color = red;
    right_color = blue;
    set(fig,'defaultAxesColorOrder',[left_color; right_color]);
    hold on
    grid on
    yyaxis right
    set(gca,'FontName','times','FontSize',10)
    ylabel('Recession rate ($m/yr$)','Interpreter','LaTeX','FontSize',13)
    p1 = plot(ALLdata(I,1),ALLdata(I,6),'Color','k');
    p2 = plot(ALLdata(I,1),ALLdata(I,3),'Color',blue);
    plot(ALLdata(I,1),ALLdata(I,3),'s','MarkerEdgeColor',blue,'MarkerFaceColor',blue)
    drawnow
    
    yyaxis left
    set(gca,'FontName','times','FontSize',10)
    ylabel('BWA ($m^{2}$)','Interpreter','LaTeX','FontSize',13)
    xlabel('Years','Interpreter','LaTeX','FontSize',13)
    text(2012, max(ALLdata(I,2)), unit{ii},'FontSize',15)
    p3 = plot(ALLdata(I,1),ALLdata(I,5),'--k');
    p4 = plot(ALLdata(I,1),ALLdata(I,2),'--','Color',red);
    plot(ALLdata(I,1),ALLdata(I,2),'d','MarkerEdgeColor',red,'MarkerFaceColor',red)
    xlim([1992.5 2003.5])
    legend([p1 p2 p3 p4 ],{'Lee','Ours','Lee','Ours'},'Location','northeast')
    drawnow
       
end

%% 7. Scatter plots for Recession and BWA and decadal scale relationships

close all
clear,clc

load('NN_Lee_ALL_REC_BWA')

% Ouliers for BWA for one value of MHWS
outliers_bwa = [52.16,33.82;49.02,25.33;40.24,16.09;31.7,15.56;22.29,1.568];

% load('NN_Lee2017_ALL_REC_BWA') % Updated value of MHWS
% outliers_bwa = [58.47,44.18; 56.55,33.82; 53.09,25.33;...
%     39.53,16.09; 31.11,15.56; 25.69,1.568]; % Updated value of MHWS

error_bwa = 2*nanstd(dif_bwa);
error_rec = 2*nanstd(dif_rec);

% Scatter plots for recession and BWA

green = 1/255*[3,188,33];
red = 1/255*[235,6,3];
blue = 1/255*[2,6,200];

% These are the outliers for recession rate.
outliers_rec = [0,5.724; 0,2.158; 6.02,2.285; 1.88,0.02774; 1.19,3.142];

figure(88)
subplot(2,2,1)
hold on
grid on
title({'\bf North Norfolk cliffs';...
    '\bf (a) Recession rate \boldmath$ (m/yr)$'},'Interpreter','LaTeX');
set(gca,'FontName','times','FontSize',15)
ylabel('Lee','Interpreter','LaTeX','FontSize',16)
xlabel('Ours','Interpreter','LaTeX','FontSize',16)
plot(ALLdata(:,3),ALLdata(:,6),'o','MarkerSize',5.9,'MarkerEdgeColor',green)
plot(outliers_rec(:,1),outliers_rec(:,2),'o','MarkerSize',6,...
    'MarkerEdgeColor',blue)
plot(0:0.1:(max(ALLdata(:,3)+10)),0:0.1:(max(ALLdata(:,3))+10),'k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,3)+15)))+error_rec,(0:0.1:(max(ALLdata(:,3))+15)),'--k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,3)+15)))-error_rec,(0:0.1:(max(ALLdata(:,3))+15)),'--k',...
    'LineWidth',0.75)
xlim([0 20])
ylim([0 20])

subplot(2,2,3)
hold on
grid on
plot(ALLdata(:,2),ALLdata(:,5),'o','MarkerSize',5.9,'MarkerEdgeColor',green)
plot(outliers_bwa(:,1),outliers_bwa(:,2),'o','MarkerSize',6,...
    'MarkerEdgeColor',red)
plot(0:0.1:(max(ALLdata(:,2))+30),0:0.1:(max(ALLdata(:,2))+30),'k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,2))+30))+error_bwa,0:0.1:(max(ALLdata(:,2))+30),'--k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,2))+30))-error_bwa,0:0.1:(max(ALLdata(:,2))+30),'--k',...
    'LineWidth',0.75)
xlim([0 80])
ylim([0 80])
set(gca,'FontName','times','FontSize',15)
title('\bf (c) Beach Wedge Area \boldmath$ \: (m^{2})$','Interpreter','LaTeX')
ylabel('Lee','Interpreter','LaTeX','FontSize',16)
xlabel('Ours','Interpreter','LaTeX','FontSize',16)

% Decadal scale relationship
figure(1)
hold on
grid on
title('Decadal Scale Relationship YEARLY data individual SDMS')
xlabel('BWA ($m^2$)','Interpreter','LaTeX','FontSize',16)
ylabel('Recession rate ($m/year$)','Interpreter','LaTeX','FontSize',16)
plot(ALLdata(:,2),ALLdata(:,3),'ob')
plot(ALLdata(:,5),ALLdata(:,6),'or')
legend('Ours','Lee')

figure(2)
hold on
grid on
title('Decadal Scale Relationship MEAN value individual SDMS')
xlabel('BWA (m^2)')
ylabel('Recession rate (m/year)')
plot(MEAN(:,1),MEAN(:,2),'ob')
plot(MEAN(:,3),MEAN(:,4),'or')
legend('Ours','Lee')

% Histograms for errors

std_bwa_NN = round(nanstd(dif_bwa),2);
std_rec_NN = round(nanstd(dif_rec),2);
mean_bwa_NN = round(nanmean(dif_bwa),2);
mean_rec_NN = round(nanmean(dif_rec),2);

figure(33)
subplot(2,2,1)
histogram(dif_rec)
hold on
set(gca,'FontName','times','FontSize',17)
title('\bf North Norfolk cliffs','FontSize',18)
xlabel('Recession rate error ($m/year$)','Interpreter','LaTeX','FontSize',18)
ylabel('Count','Interpreter','LaTeX','FontSize',18)
text(2.5,36,['mean: ', num2str(mean_rec_NN)],'FontSize',16)
text(2.5,32,['std: ', num2str(std_rec_NN)],'FontSize',16)
rectangle('Position',[2.35 28.5 3.2 10.5],'Curvature',0.1)
xlim([-6.5,6.5])

subplot(2,2,3)
histogram(dif_bwa)
hold on
xlabel('BWA error ($m^2$)','Interpreter','LaTeX','FontSize',18)
ylabel('Count','Interpreter','LaTeX','FontSize',18)
text(10.1,30,['mean: ', num2str(mean_bwa_NN)],'FontSize',16)
text(10.1,26.5,['std: ', num2str(std_bwa_NN)],'FontSize',16)
set(gca,'FontName','times','FontSize',17)
rectangle('Position',[9.5 23.5 12 9.5],'Curvature',0.1)
xlim([-26,26])


%% 8. Probability distributions

close all
clear, clc

load('NN_ALL_REC_BWA')

green = 1/255*[3,188,33];
red = 1/255*[235,6,3];

% We separate into different BWA ranges ours and Lee's data

lim1 = 5;
lim2 = 20;

zone1_ours = [];
zone2_ours = [];
zone3_ours = [];
zone1_Lee = [];
zone2_Lee = [];
zone3_Lee = [];

for ii = 1:length(ALLdata(:,2))
   
    if ALLdata(ii,2) < lim1        
        zone1_ours = [zone1_ours; ALLdata(ii,2) ALLdata(ii,3)];     
    elseif ALLdata(ii,2) > lim1 && ALLdata(ii,2) < lim2
        zone2_ours = [zone2_ours; ALLdata(ii,2) ALLdata(ii,3)];    
    else
        zone3_ours = [zone3_ours; ALLdata(ii,2) ALLdata(ii,3)];      
    end
    
    if ALLdata(ii,5) < lim1        
        zone1_Lee = [zone1_Lee; ALLdata(ii,5) ALLdata(ii,6)];       
    elseif ALLdata(ii,5) >= lim1 && ALLdata(ii,5) <= lim2
        zone2_Lee = [zone2_Lee; ALLdata(ii,5) ALLdata(ii,6)];       
    else
        zone3_Lee = [zone3_Lee; ALLdata(ii,5) ALLdata(ii,6)];        
    end
    
end

% We count the data that are found in intervals of 1 m/yr of the recession 
% rate and plot for all the data and the different zones

%% All data
lim_max = floor(max(ALLdata(:,6)))+1;
x = 0:1:lim_max;  % Here we can change the range of the intervals
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(ALLdata(:,6))             
        if ALLdata(j,3) > x(jj) && ALLdata(j,3) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    
    for j = 1:length(ALLdata(:,6))
        if ALLdata(j,6) > x(jj) && ALLdata(j,6) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end       
    end     
end

figure(7)
hold on
grid on
title('ALL')
bar(x,y_ours/sum(y_ours),'FaceColor', green)
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
xlabel('Recession (m)')
ylabel('Probability')
xlim([-0.5 20.5])
legend('Ours','Lee')

%% ZONE 1   BWA > 5 m^2

lim_max = floor(max(zone1_Lee(:,2)))+1;
x = 0:1:lim_max;
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone1_ours(:,2))
               
        if zone1_ours(j,2) > x(jj) && zone1_ours(j,2) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    for j = 1:length(zone1_Lee(:,2))
        
        if zone1_Lee(j,2) > x(jj) && zone1_Lee(j,2) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end       
    end    
end

figure(99)
subplot(3,2,1)
hold on
grid on
bar(x,y_ours/sum(y_ours),'FaceColor', green)
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
set(gca,'FontName','times','FontSize',11)
title({'\bf North Norfolk cliffs'; '\bf BWA \boldmath$< \: 5 \: m^{2}$'},...
    'Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',11.5)
xlim([-0.5 20.5])
ylim([0 1])

%% ZONE 2	BWA 5-20 m^2

lim_max = floor(max(zone2_Lee(:,2)))+1;
x = 0:1:lim_max;
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone2_ours(:,2))
               
        if zone2_ours(j,2) > x(jj) && zone2_ours(j,2) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    
    for j = 1:length(zone2_Lee(:,2))
        
        if zone2_Lee(j,2) > x(jj) && zone2_Lee(j,2) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end    
    end     
end

figure(99)
subplot(3,2,3)
hold on
grid on
bar(x,y_ours/sum(y_ours),'FaceColor', green)
set(gca,'FontName','times','FontSize',11)
title('\bf BWA 5 - 20 \boldmath$m^2$','Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',11.5)
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
legend('Ours','Lee')
xlim([-0.5 20.5])
ylim([0 1])

%% ZONE 3	BWA > 20 m^2

lim_max = floor(max(zone3_Lee(:,2)))+1;
x = 0:1:lim_max;
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone3_ours(:,2))
               
        if zone3_ours(j,2) > x(jj) && zone3_ours(j,2) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    
    for j = 1:length(zone3_Lee(:,2))
        
        if zone3_Lee(j,2) > x(jj) && zone3_Lee(j,2) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end      
    end     
end

figure(99)
subplot(3,2,5)
hold on
grid on
bar(x,y_ours/sum(y_ours),'FaceColor', green)
set(gca,'FontName','times','FontSize',11)
title('\bf BWA \boldmath$> \: 20 \: m^{2}$','Interpreter','LaTeX')
xlabel('Recession rate $(m/yr)$','Interpreter','LaTeX','FontSize',12)
ylabel('Probability','Interpreter','LaTeX','FontSize',11.5)
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
xlim([-0.5 20.5])
ylim([0 1])
