%{ 
    Script develovep to obtain the CCO coastal profile data of Suffolk and
    calculate the annual recession rate (rec) and the beach wegde area
    (BWA) using the detrended method to obtain the top and toe cliff and
    calculating the BWA using the area below the curve. After that the
    decadal scale relationship and the probability distribution between
    BWA and rec are calculated. A hierarchical clustering, a BWA vs 
    frecuency and a loglog plot of BWA vs mean recession rate scripts are
    also included.

    This script was completed on November 29, 2019 (by P.M.L. Granada)
%}

%% 1. We extract those profiles that contain the Reg_ID identifiers we are
% 	  interested in and add the corresponding date.

clc,clear

% Names of the unprotected location used in the previous work (Lee, 2008)
% prfID = {'3c00071', '3c00088', '3c00176', '3c00204', '3c00220',...
%          '3c00245', '3c00263', '3c00280', '3c00295'};
% Names of the unprotected and completed sites in the 25 years
prfID = {'3c00088','3c00176','3c00204','3c00220','3c00245','3c00263',...
    '3c00280'};

% Loading .txt data
G = dir('*.txt');
G = struct2cell(G);
G = G(1,:)';
DAT = [];
TEX = [];

% We go through all the files comparing the Reg_IDs and filling in the 
% variables for numeric data and for text data
for ii = 1:length(G)
    
    fprintf('Processing file %d of %d - %s\n',ii,length(G),G{ii})
    fid = fopen(G{ii}); 
    prf = textscan(fid,'%f %f %f %f %s %s %s',...
    'Delimiter','\t','CollectOutput',1,'Headerlines',1);
    II = zeros(size(prf{1,2},1),length(prfID));
    STR = (prf{1,2}(:,3));
    
    for jj = 1:length(prfID)
        
        I = (strcmp(STR,prfID{jj}));
        II(:,jj) = I;
    end
    
    II = sum(II,2); 
    if sum(II) > 0
        II = logical(II);
        DAT = [DAT; [(prf{1,1}(II,:)) datenum(repmat({G{ii}(10:17)},...
            sum(II),1), 'yyyymmdd')]];
        TEX = [TEX; [prf{1,2}(II,:) repmat({G{ii}(10:17)},sum(II),1)]];
    end
    fclose(fid);   
end

% We save all the files we are interested in according to their type (data
% or text), in .mat format, separated by their identifiers

for jj = 1:length(prfID)
    
    fprintf('Saving file %d of %d - %s\n',jj,length(prfID),prfID{jj})
    I = (strcmp(TEX(:,3),prfID{jj}));
    dat = DAT(I,:);
    tex = TEX(I,:);
    save([prfID{jj},'.mat'],'dat','tex')
    
end

%% 2. Script to plot all profiles of one location in the same Figure

clc,clear

load 3c00245

figure(142)
hold on
grid on
colorbar('Ticks',[0.02,0.248,0.515,0.75,0.9809],'TickLabels',{'1993',...
    '1999','2006','2012','2018'})
xlabel('Chainage (m)')
ylabel('Elevation (m)')

% To plot by date we get only one value per profile
yr = unique(tex(:,4));
clr = colormap(jet(length(yr)));

% We make a loop to represent all the profiles in the same figure
for ii = 1 : length(yr)
    
    % We use a logical operator to not mix different dates
    I = (strcmp(tex(:,4),yr{ii}));
    plot(dat(I,4),dat(I,3),'Color',clr(ii,:))
    drawnow
    
end

%% 3. Script to screen the profiles that are duplicated

close all; clear,clc

G = dir('3c00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id);

    yr = unique(dat(:,5));
    DAT = [];
    TEX = [];
    for ii = 1 : length(yr)

        i0 = find(dat(:,5) == yr(ii));
        x = dat(i0,4);
        [~, ia, ic] = unique(x);
        DAT = [DAT; dat(i0(ia),:)];
        TEX = [TEX; tex(i0(ia),:)];

    end

    dat = DAT;
    tex = TEX;
    
    fprintf('File %d of %d screened - %s\n',jj,length(G),G{jj}(1:7))
    save(id,'dat','tex')
end

%% 4. Script to extract winter to winter profiles. Here we also exclude
%    the data taken in close months.

clear,clc

G = dir('3c00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id);
    
    DAT = [];
    TEX = [];
    DIF = [];   
    m = tex(:,4);
    
    for ii = 1 : length(m)
         % To be the profile taken in the same months each year
        wint = str2double(m{ii}(5:6));
        
        if wint < 4           
            DAT = [DAT; dat(ii,:)];
            TEX = [TEX; tex(ii,:)];
        end
    end
    
    yr = unique(DAT(:,5));
    
    for nn = 2: length(yr)
        
        dif = yr(nn) - yr(nn-1);
        DIF = [DIF; dif];
        
    end
    
    % If the difference between data is less than 100 days we don't take
    % the profile because is taken in the same year, on a close date
    for n = 2 : length(yr)
               
        if DIF(n-1) < 100            
            yr(n) = NaN;           
        end
    end
    
    DAT2 = [];
    TEX2 = [];
    
    for nn = 1: length(yr)        
       for i = 1 : length(DAT(:,1)) 
           
           if DAT(i,5) == yr(nn)              
               DAT2 = [DAT2; DAT(i,:)];
               TEX2 = [TEX2; TEX(i,:)];
           end
       end
    end
    
    dat = DAT2;
    tex = TEX2;

    fprintf('Saving new file %d of %d - %s\n',jj,length(G),G{jj}(1:7))
    save(['Winter', id],'dat','tex')     
end

%{
% IF WE DON'T REMOVE UNITS 3C00071 AND 3C00295
% After that we remove the years with new defense on unit 3c00295 and we
% also remove the profiles of 3c00071 that don't correspond to the location
%% Remove years with new defense on unit 3c00295

id = 'Winter3c00295.mat';
load(id);

DAT = [];
TEX = [];

b = tex(:,4);

for i = 1 : length(b)
    
    % To be the years where we don't have defenses
    no_defense = str2double(b{i}(1:4));
    
    if no_defense < 2003
        
        DAT = [DAT; dat(i,:)];
        TEX = [TEX; tex(i,:)];
    end
end

dat = DAT;
tex = TEX;

save(id,'dat','tex')

%% We eliminate the prf of 3c00071 that don't correspond to the location
id = 'Winter3c00071.mat';
load(id);

DAT = [];
TEX = [];

b = tex(:,4);

for j = 1 : length(dat(:,2))
    
    rigth_location = str2double(b{j}(1:4));  % To eliminate wrong location
    
    if rigth_location < 2002 || rigth_location > 2013
        %     if dat(j,2) < 2.884e5
        DAT = [DAT; dat(j,:)];
        TEX = [TEX; tex(j,:)];
    end
end

dat = DAT;
tex = TEX;

save(id,'dat','tex')

%}

%% 5.1 Script to extract the cliff top using the detrended method and
%  calculate the recession rate for all the profiles.
%  5.2 Script to extract the cliff toe using the detrended method and
%  calculate the BWA for all the profiles, using the method that involve the
%  local min and ckecking that the BWA is under a maximum value (bwa_max).
%  The two scripts could be join to avoid the repetition of certain loops

clear,clc

% Names of the Reg_IDs that Lee used, the unprotected sites
prfID = dir('Winter*');
prfID = struct2cell(prfID);
prfID = prfID(1,:)';

% We take MHWS from 2017 database of DEFRA
% mhws = [0.97,0.97,0.94,0.93,0.93,0.92,0.92,0.90,0.90]; 9 profiles (with
% 3c00071 and 3c00295)
mhws = [0.97,0.94,0.93,0.93,0.92,0.92,0.90]; % 7 profiles (without
% 3c00071 and 3c00295 that are incomplete or with new defenses)
bwa_max = 80.0;  % It's based on the Lee's results.

% Variables that we are going to save
ALLdata = [];
ALLnames = [];
MEAN = [];
rec_tot = [];

for jj = 1:length(prfID)
    
    id = prfID{jj};
    load(id);
    
    yr = unique(dat(:,5));
    
    % 5.1. RECESSION RATE
    
    TOP_X = [];
    TOP_Z = [];
    
    for ii = 1 : length(yr)
        
        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);
        
        x_interp = x(1):0.01:x(end);
        z_interp = interp1(x,z,x_interp,'linear');
        
        % Detrending
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1-z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);
        
        % We calculate the max that correspond to the top and we use the
        % interpolate points to obtain it. For be rigorous, we should
        % search the values of the profiles that correspond to those points,
        % but it's not neccesary because the interpolation is very accurate
        % (+/- 0.01)
        
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        top_z = z_interp(find(max(z_detrend)==z_detrend,1));
        
        % Below we calculate the top with more accuracy using the previous
        % top for the interpolation and the toe (obtained as the first
        % minimun after the cliff) as the limit
        
        x_interp_top2 = top_x:0.01:x(end);
        z_interp_top2 = interp1(x,z,x_interp_top2,'linear');
        z0 = z_interp_top2(end);
        z1 = z_interp_top2(1);
        x0 = x_interp_top2(end);
        x1 = x_interp_top2(1);
        a = (z1-z0)/(x1-x0);
        z_detrend_top2 = z_interp_top2 - (a*x_interp_top2);
        
        TF1 = islocalmin(z_detrend_top2);
        
        toe_z = z_interp_top2(TF1);
        % Condition to extract the first min in the case that are several
        if length(toe_z) > 1
            toe_z = toe_z(1);
        end
        
        TF2 = isempty(toe_z);
        if TF2 == 0
            pos_toe = find(z_interp_top2 == toe_z);
            top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
            top_z = z_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
        end
        
        % Condition for incomplete profiles
        if top_z < 3
            top_z = NaN;
            top_x = NaN;
        end
        
        TOP_X = [TOP_X; top_x];
        TOP_Z = [TOP_Z; top_z];
        
    end
    top_xz = [TOP_X,TOP_Z];
    
    % Recession rate calculation
    rec = zeros([length(top_xz) 1]);
    rec(1) = 0.0;
    for ii = 2:length(top_xz)
        if top_xz(ii,1)*top_xz(ii-1,1) <= 0
            rec(ii) = abs(top_xz(ii,1)) + abs(top_xz(ii-1,1));
        else
            rec(ii) = abs(abs(top_xz(ii,1)) - abs(top_xz(ii-1,1)));
        end
    end
    
    % This years the TOP is not correctly automaticaly taken (we realise 
    % during the analysis of outliers), so we take them by hand:
    if str2double(id(12:13)) == 88
            rec(25) = 0.11; 
            rec(26) = 0.21;  
    end
        
    % 5.2 BEACH WEDGE AREA
    
    BWA = [];
    
    for ii = 1 : length(yr)
        
        % First we calculate top and toe cliff for each profile as earlier
        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);
        
        x_interp = x(1):0.01:x(end);
        z_interp = interp1(x,z,x_interp,'linear');
        
        % Detrending
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);
        
        % We calculate the min and the max that correspond to toe and top.
        
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        top_z = z_interp(find(max(z_detrend)==z_detrend,1));
        
        % We interpolate again and we repeat the detrending...
        
        x_interp_top = top_x:0.01:x(end);
        z_interp_top = interp1(x,z,x_interp_top,'linear');
        z0 = z_interp_top(end);
        z1 = z_interp_top(1);
        x0 = x_interp_top(end);
        x1 = x_interp_top(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend_top = z_interp_top - (a*x_interp_top);
        
        TF_top = islocalmin(z_detrend_top);       
        toe_x = x_interp_top(TF_top);
        toe_z = z_interp_top(TF_top);
        
        if length(toe_x) > 1  % To extract the first minimun
            toe_x = toe_x(1);
            toe_z = toe_z(1);
        end
        
        % We calculate again the top using only the values until the toe
        
        if isempty(toe_z) == 0
            pos_toe = find(z_interp_top == toe_z);
            top_x = x_interp_top(find(max(z_detrend_top(1:pos_toe))==z_detrend_top,1));
            top_z = z_interp_top(find(max(z_detrend_top(1:pos_toe))==z_detrend_top,1));
        end
        
        if top_z < 3  % Condition for the incomplete profiles
            top_z = NaN;
            top_x = NaN;
            toe_x = NaN;
            toe_z = NaN;
        end
        
        % First calculation of BWA
        
        xz_cut = find(z_interp >= mhws(jj),1,'last');
        z_interp = z_interp - mhws(jj);
        xz_toe = find(x_interp >= toe_x,1,'first');
        bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
        
        % We check if we have a TOE. If we don't then bwa = NaN. This can
        % happen when the profile is not completed
        if isempty(xz_toe) == 1
            bwa = NaN;
        end
        
%         % Script lines for check the methodology
%         x_interp(xz_cut)
%         x_interp(xz_toe)
%         figure(81)
%         plot(x_interp_top,z_detrend_top,'g', x_interp_top(TF_top),...
%              z_detrend_top(TF_top),'r*')
%         hold on; grid on
%         plot(x_interp_top,z_interp_top,'b')
        
        % In the location 3c00088 we have a sharp accretion. Aerials show
        % that this is due to the northerly migration of Benacre Ness 
        % building the beach outwards. That's why we change the bwa_max for
        % this location
        if str2double(id(12:13)) == 88
            bwa_max = 300;
        else
            bwa_max = 80;
        end

        % If the bwa obtained is bigger that bwa_max we repeated the
        % calculation of the toe, as the second local minimun and use it
        % for calculate the bwa again
        if bwa > bwa_max
            
            % We interpolate again because the top may has changed
            x_interp_top2 = top_x:0.01:x(end);
            z_interp_top2 = interp1(x,z,x_interp_top2,'linear');
            z0 = z_interp_top2(end);
            z1 = z_interp_top2(1);
            x0 = x_interp_top2(end);
            x1 = x_interp_top2(1);
            a = (z1 - z0)/(x1-x0);
            z_detrend_top2 = z_interp_top2 - (a*x_interp_top2);
            
            TF_top2 = islocalmin(z_detrend_top2);            
            toe_x = x_interp_top2(TF_top2);
            toe_z = z_interp_top2(TF_top2);
            
            if length(toe_x) > 1   % Condition to extract the second min
                toe_x = toe_x(2);
                toe_z = toe_z(2);
            end
            % We calculate again the top using only the values until the toe           
            if isempty(toe_z) == 0
                pos_toe = find(z_interp_top2 == toe_z);
                top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe)) == z_detrend_top2,1));
            end
            
            % Second calculation of BWA           
            xz_toe = find(x_interp >= toe_x,1,'first');
            bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
            
            if isempty(xz_toe) == 1
                bwa = NaN;
            end
            
            if bwa > bwa_max  % Toe and bwa calculation if bwa > bwa_max still
                
                toe_x = x_interp_top2(TF_top2);
                toe_z = z_interp_top2(TF_top2);
                
                if length(toe_x) > 2   % Condition to extract the third min
                    toe_x = toe_x(3);
                    toe_z = toe_z(3);
                end
                
                if length(toe_x) > 1   % If exits
                    toe_x = toe_x(2);
                    toe_z = toe_z(2);
                end
                
                % We calculate again the top using only the values until the toe
                
                if isempty(toe_z) == 0
                    pos_toe = find(z_interp_top2 == toe_z);
                    top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe)) == z_detrend_top2,1));
                end
                
                % Third calculation of BWA               
                xz_toe = find(x_interp >= toe_x,1,'first');
                bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
                
                if isempty(xz_toe) == 1
                    bwa = NaN;
                end               
            end
        end      
        BWA = [BWA; bwa];
    end
    
    % Here we calculate the mean value of BWA using the same years of REC
    BWA_mean = [];
    BWA_mean = [BWA_mean; BWA(1)];
    
    for k = 1:length(BWA)-1      
        if isnan(BWA(k))
            BWA_mean = [BWA_mean; BWA(k)];
        else
            BWA_mean = [BWA_mean; nanmean([BWA(k),BWA(k+1)])];
        end    
    end
    
    % We save all the BWA, REC in one unique table, with the corresponding
    % date and we use another table for save the corresponding survey unit.
    % In this way, later it will be easier to find the outliers
    date = str2num(datestr(yr,'yyyy'));
    unit = tex(1,3);
    
    % We calculate the mean value for each monitoring site   
    Allmean = [mean(BWA,'omitnan') mean(rec,'omitnan')]; 
    MEAN = [MEAN; Allmean];
    
    % We calculate the total recession for the 24 years
    rec_tot = [rec_tot; sum(rec,'omitnan')];
    
    % We create a time vector for populate with NaN the missing years
    vt = 1993:1:2018;
    
    for n=1:length(vt)
        
        idata = find(date==vt(n));
        
        if isempty(idata)
            dumOurs = NaN(1,3);
            dumOurs(1,1) = vt(n);
        else
            dumOurs = [date(idata) BWA_mean(idata) rec(idata)];
        end
        
        AllData(n,:) = dumOurs;
        Allnames(n,:) = unit{1};
    end
    
    ALLdata = [ALLdata; AllData];
    ALLnames = [ALLnames; Allnames];
    
end

save(['S_winter_ALL_REC_BWA', '.mat'],'ALLdata','ALLnames','MEAN','rec_tot')
fprintf(' S_winter_ALL_REC_BWA calculated and saved ')

%% 06 Plotting REC and BWA per year

clear,clc

load('S_winter_ALL_REC_BWA.mat')

red = 1/255*[235,6,3];
blue = 1/255*[2,6,200];

% First we eliminate the year 1993, because we can't calculate BWA and
% recession rate without the 1992 data
i1993 = find(ALLdata(:,1)==1993);
ALLdata(i1993,2) = NaN;
ALLdata(i1993,3) = NaN;

% To plot by profile
ALLnames = string(ALLnames);
unit = unique(ALLnames);

% We make a loop to represent all the profiles in the same figure
for ii = 1 : length(unit)
    
    I = (strcmp(ALLnames,unit{ii}));
    
    fig = figure(ii);
    left_color = red;
    right_color = blue;
    set(fig,'defaultAxesColorOrder',[left_color; right_color]);
    hold on
    grid on
    yyaxis right
    set(gca,'FontName','times','FontSize',10)
    ylabel('Recession rate ($m/yr$)','Interpreter','LaTeX','FontSize',13)
    plot(ALLdata(I,1),ALLdata(I,3),'Color',blue)
    plot(ALLdata(I,1),ALLdata(I,3),'s','MarkerEdgeColor',blue,'MarkerFaceColor',blue)
    drawnow
    
    yyaxis left
    set(gca,'FontName','times','FontSize',10)
    ylabel('BWA ($m^{2}$)','Interpreter','LaTeX','FontSize',13)
    xlabel('Years','Interpreter','LaTeX','FontSize',13)
    text(2012, max(ALLdata(I,2)), unit{ii},'FontSize',15)
    plot(ALLdata(I,1),ALLdata(I,2),'--','Color',red)
    plot(ALLdata(I,1),ALLdata(I,2),'d','MarkerEdgeColor',red,'MarkerFaceColor',red)
    xlim([1993.5 2018.5])
    drawnow      
    
end

%% 7.  Decadal scale relationship (all and by profile)

close all; clear,clc

load('S_winter_ALL_REC_BWA')

% First we eliminate the year 1993, because we can't calculate rec or bwa 
% without data from 1992 
i1993 = find(ALLdata(:,1)==1993);
ALLdata(i1993,2) = NaN;
ALLdata(i1993,3) = NaN;

% Plotting decadal scale relationship
figure(71)
hold on
grid on
title('Decadal Scale Relationship YEARLY data individual SDMS')
xlabel('BWA (m^2)')
ylabel('Recession rate (m/year)')
plot(ALLdata(:,2),ALLdata(:,3),'ok')

figure(72)
hold on
grid on
title('Decadal Scale Relationship MEAN value individual SDMS')
xlabel('BWA (m^2)')
ylabel('Recession rate (m/year)')
plot(MEAN(:,1),MEAN(:,2),'ok')

% Plotting by profile
ALLnames = string(ALLnames);
unit = unique(ALLnames);

for ii = 1 : length(unit)
    
    I = (strcmp(ALLnames,unit{ii}));
    
    figure(ii+20)
    hold on
    grid on    
    xlabel('BWA (m^2)')
    ylabel('Recession rate (m/year)')
    plot(ALLdata(I,2),ALLdata(I,3),'ok')
    text(max(ALLdata(I,2))-5, max(ALLdata(I,3)), unit{ii},'FontSize',15)
    drawnow
    ylim([0 20])
    xlim([0 85])
    
end

%% 08. Program to create hierarchical cluster with BWA and REC and be
%      able to divide the probability zones in an elegant way
close all; clc, clear

% We load rec and bwa of the North Norfolk and Suffolk profiles and screen 
% the NaN. We also screen the BWA bigger than 85 m^2 that correspond to
% increasing accretion due to the northerly migration of Benacre Ness 
% building the beach outward, that it's a special case that falsify the
% results

load('S_winter_ALL_REC_BWA.mat')
bwa_recNaN = [ALLdata(:,2), ALLdata(:,3)];
load('NN_winter_ALL_REC_BWA.mat')
bwa_recNaN = [bwa_recNaN; ALLdata(:,2),ALLdata(:,3)];
bwa_rec = bwa_recNaN(isnan(bwa_recNaN(:,1))==0 & isnan(bwa_recNaN(:,...
    2))==0 & bwa_recNaN(:,1)< 85,:);

% We plot the dendrogram and the cluster for 2 division

figure(200)
tree = linkage(bwa_rec,'average');
[~,T2,~] = dendrogram(tree,2,'ColorThreshold','default');
title('Hierarchical clustering','Interpreter','LaTeX',...
    'FontSize',15)
set(gca,'FontName','times','FontSize',16)
ylim([0 50])

figure(201)
hold on
colours = 'rbk';
for i=1:2
    
    plot(bwa_rec(T2==i,1),bwa_rec(T2==i,2),'.','Color',colours(i),'MarkerSize',12.5)
    
end
legend({'1','2'})
set(gca,'FontName','times','FontSize',20)
ylabel('Recession rate $(m/yr)$','Interpreter','LaTeX','FontSize',25)
xlabel('BWA ($m^{2}$)','Interpreter','LaTeX','FontSize',25)

% We plot the dendrogram and the cluster for 3 division
figure(300)
tree = linkage(bwa_rec,'average');
[~,T3,~] = dendrogram(tree,3,'ColorThreshold','default');
title('Hierarchical clustering','Interpreter','LaTeX',...
    'FontSize',15)
ylim([0 50])
set(gca,'FontName','times','FontSize',16)

figure(301)
hold on
grid on   
plot(bwa_rec(T3==2,1),bwa_rec(T3==2,2),'.','Color','k','MarkerSize',12.5)
plot(bwa_rec(T3==3,1),bwa_rec(T3==3,2),'.','Color','b','MarkerSize',12.5)
plot(bwa_rec(T3==1,1),bwa_rec(T3==1,2),'.','Color','r','MarkerSize',12.5)
legend({'Zone 1','Zone 2',' Zone 3'},'FontSize',20)
set(gca,'FontName','times','FontSize',25)
ylabel('Recession rate $(m/yr)$','Interpreter','LaTeX','FontSize',25)
xlabel('BWA ($m^{2}$)','Interpreter','LaTeX','FontSize',25)

% We calculate the thresholds between each zone
lim_max1_3 = max(bwa_rec(T3==1,1));
lim_min1_3 = min(bwa_rec(T3==1,1));
lim_max2_3 = max(bwa_rec(T3==2,1));
lim_min2_3 = min(bwa_rec(T3==2,1));
lim_max3_3 = max(bwa_rec(T3==3,1));
lim_min3_3 = min(bwa_rec(T3==3,1));

lim_max1_2 = max(bwa_rec(T2==1,1));
lim_min1_2 = min(bwa_rec(T2==1,1));
lim_max2_2 = max(bwa_rec(T2==2,1));
lim_min2_2 = min(bwa_rec(T2==2,1));

%% 9. Probability distribution

load('S_winter_ALL_REC_BWA')

% First we eliminate the year 1993, because we can't calculate rec or bwa 
% without data from 1992
i1993 = find(ALLdata(:,1)==1993);
ALLdata(i1993,2) = NaN;
ALLdata(i1993,3) = NaN;

% We separate into different BWA ranges

lim1 = 21;
lim2 = 52;

zone1 = [];
zone2 = [];
zone3 = [];

for ii = 1:length(ALLdata(:,2))
   
    if ALLdata(ii,2) < lim1        
        zone1 = [zone1; ALLdata(ii,2) ALLdata(ii,3)];     
    elseif ALLdata(ii,2) > lim1 && ALLdata(ii,2) < lim2
        zone2 = [zone2; ALLdata(ii,2) ALLdata(ii,3)];    
    else
        zone3 = [zone3; ALLdata(ii,2) ALLdata(ii,3)];      
    end
    
end

% We count the data that are found in intervals of 1 m/yr of the recession 
% rate and plot for all the data and the different zones

% All data
lim_max = floor(max(ALLdata(:,3)))+1;
x = 0:1:lim_max;  % Here we can change the range of the intervals
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(ALLdata(:,3))
               
        if ALLdata(j,3) > x(jj) && ALLdata(j,3) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end 
end

prob = prob/sum(prob);
green = 1/255*[3,188,33];

figure(74)
hold on
grid on
title('ALL')
bar(x,prob,'FaceColor', green)
xlabel('Recession (m/yr)')
ylabel('Probability')
xlim([-0.5 20])
ylim([0 1])

% ZONE 1   BWA < 21 m^2
x = 0:1:lim_max;
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone1(:,2))
               
        if zone1(j,2) > x(jj) && zone1(j,2) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end    
end

prob = prob/sum(prob);

figure(99)
subplot(3,2,2)
hold on
grid on
bar(x,prob,'FaceColor', green)
set(gca,'FontName','times','FontSize',11)
title({'\bf Suffolk cliffs'; '\bf BWA \boldmath$< \: 21 \: m^{2}$'},'Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',11.5)
xlim([-0.5 20])
ylim([0 1])

% ZONE 2   BWA 21 - 52 m^2
x = 0:1:lim_max;
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone2(:,2))
               
        if zone2(j,2) > x(jj) && zone2(j,2) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end    
end

prob = prob/sum(prob);

figure(99)
subplot(3,2,4)
hold on
grid on
bar(x,prob,'FaceColor', green)
set(gca,'FontName','times','FontSize',11)
title('\bf BWA 21 - 52 \boldmath$m^2$','Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',11.5)
xlim([-0.5 20])
ylim([0 1])

% ZONE 3   BWA > 52 m^2
x = 0:1:lim_max;
prob = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone3(:,2))
               
        if zone3(j,2) > x(jj) && zone3(j,2) < x(jj+1)
            prob(jj) = prob(jj) + 1;
        end
    end   
end
prob = prob/sum(prob);

figure(99)
subplot(3,2,6)
hold on
grid on
bar(x,prob,'FaceColor', green)
set(gca,'FontName','times','FontSize',11)
title('\bf BWA \boldmath$> \: 52 \: m^{2}$','Interpreter','LaTeX')
xlabel('Recession rate $(m/yr)$','Interpreter','LaTeX','FontSize',12)
ylabel('Probability','Interpreter','LaTeX','FontSize',11.5)
xlim([-0.5 20])
ylim([0 1])

% To look for outliers
% ALLdata(find(ALLdata(:,3)==zone3(61,2)),1)
% ALLnames = string(ALLnames);
% ALLnames(find(ALLdata(:,3)==zone3(61,2)),1)


%% 10. Script to plot in different ways the BWA frecuency

close all; clc, clear
% North Norfolk
load('NN_winter_ALL_REC_BWA.mat')

green = 1/255*[3,188,33];

lim_max = floor(max(ALLdata(:,2)))+1;
x1 = 0:1:lim_max;  % Here we can change the range of the intervals
freq1 = zeros(1,length(x1));

for jj = 1:length(x1)-1
    
    for j = 1:length(ALLdata(:,2))
               
        if ALLdata(j,2) > x1(jj) && ALLdata(j,2) < x1(jj+1)
            freq1(jj) = freq1(jj) + 1;
        end
    end 
end

figure(81)
subplot(2,2,1)
hold on
grid on
title('North Norfolk')
bar(x1,freq1,'FaceColor', green)
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ($m^2$)','Interpreter','LaTeX','FontSize',20)
ylabel('Frequency','Interpreter','LaTeX','FontSize',20)
xlim([-1 80])
ylim([0 15])

subplot(2,2,2)
hold on
grid on
title('North Norfolk')
plot(log(x1),log(freq1),'ok')
set(gca,'FontName','times','FontSize',16)
xlabel('log(BWA ($m^2$))','Interpreter','LaTeX','FontSize',20)
ylabel('log(frequency)','Interpreter','LaTeX','FontSize',20)
xlim([0 6])
ylim([0 3])

% Suffolk
load('S_winter_ALL_REC_BWA.mat')

lim_max = floor(max(ALLdata(:,2)))+1;
x = 0:1:lim_max;  % Here we can change the range of the intervals
freq = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(ALLdata(:,2))
               
        if ALLdata(j,2) > x(jj) && ALLdata(j,2) < x(jj+1)
            freq(jj) = freq(jj) + 1;
        end
        
    end 
end

figure(81)
subplot(2,2,3)
hold on
grid on
title('Suffolk')
bar(x,freq,'FaceColor', green)
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ($m^2$)','Interpreter','LaTeX','FontSize',20)
ylabel('Frequency','Interpreter','LaTeX','FontSize',20)
xlim([-1 80])
ylim([0 15])

subplot(2,2,4)
hold on
grid on
title('Suffolk')
plot(log(x),log(freq),'ok')
set(gca,'FontName','times','FontSize',16)
xlabel('log(BWA ($m^2$))','Interpreter','LaTeX','FontSize',20)
ylabel('log(frequency)','Interpreter','LaTeX','FontSize',20)
xlim([0 6])
ylim([0 3])

% ALL
freq2 = freq(1:length(freq1)) +freq1;
figure(88)
subplot(1,2,1)
hold on
grid on
title('All data (intervals 1 m^2)')
bar(x1,freq2,'FaceColor', green)
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ($m^2$)','Interpreter','LaTeX','FontSize',20)
ylabel('Frequency','Interpreter','LaTeX','FontSize',20)
xlim([-1 80])
ylim([0 20])

subplot(1,2,2)
hold on
grid on
title('All data (intervals 1 m^2)')
plot(log(x1),log(freq2),'ok')
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ($m^2$)','Interpreter','LaTeX','FontSize',20)
ylabel('Frequency','Interpreter','LaTeX','FontSize',20)

%% 11. Script to draw the loglog plot of the BWA vs mean recession rate
%  (calculated as the mean of the recession rate values comprise on 5 m^2
%  BWA intervals) for each location and for all

% NORTH NORFOLK
clear
load('NN_winter_ALL_REC_BWA.mat')

lim_max_2 = floor(max(ALLdata(:,2)))+5;
x2 = 1:5:lim_max_2;  % Here we set the range of the intervals to 5 m^2
freq2 = zeros(1,length(x2));

rec_mean_2 = [];

for jj = 1:length(x2)-1
    bwa_freq = 0;
    rec_freq = 0;
    for j = 1:length(ALLdata(:,2))
               
        if ALLdata(j,2) > x2(jj) && ALLdata(j,2) < x2(jj+1)
            freq2(jj) = freq2(jj) + 1;
            rec_freq = rec_freq + ALLdata(j,3);
        end      
    end
    if freq2 (jj) == 0
        rec_mean_2 = [rec_mean_2; NaN];
    else
        rec_mean_2 = [rec_mean_2; rec_freq/freq2(jj)];
    end
end

figure(140)
subplot(2,2,1)
hold on
grid on
title('North Norfolk')
plot(x2(1:end-1),rec_mean_2,'ok')
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ','Interpreter','LaTeX','FontSize',20)
ylabel('Mean recession ','Interpreter','LaTeX','FontSize',20)
subplot(2,2,2)
hold on
grid on
title('North Norfolk loglog')
plot(log(x2(1:end-1)),log(rec_mean_2),'ok')
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ','Interpreter','LaTeX','FontSize',20)
ylabel('Mean recession ','Interpreter','LaTeX','FontSize',20)

% SUFFOLK
load('S_winter_ALL_REC_BWA.mat')

lim_max1 = floor(max(ALLdata(:,2)))+4;
x1 = 1:5:lim_max1;  % Here we set the range of the intervals to 5 m^2
freq1 = zeros(1,length(x1));

rec_mean = [];

for jj = 1:length(x1)-1
    bwa_freq = 0;
    rec_freq = 0;
    for j = 1:length(ALLdata(:,2))
               
        if ALLdata(j,2) > x1(jj) && ALLdata(j,2) < x1(jj+1)
            freq1(jj) = freq1(jj) + 1;
            rec_freq = rec_freq + ALLdata(j,3);
        end       
    end
    if freq1 (jj) == 0
        rec_mean = [rec_mean; NaN];
    else
        rec_mean = [rec_mean; rec_freq/freq1(jj)];
    end
end

figure(140)
subplot(2,2,3)
hold on
grid on
title('Suffolk')
plot(x1(1:end-1),rec_mean,'ok')
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ','Interpreter','LaTeX','FontSize',20)
ylabel('Mean recession ','Interpreter','LaTeX','FontSize',20)
subplot(2,2,4)
hold on
grid on
title('Suffolk loglog')
plot(log(x1(1:end-1)),log(rec_mean),'ok')
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ','Interpreter','LaTeX','FontSize',20)
ylabel('Mean recession','Interpreter','LaTeX','FontSize',20)


% All data

load('S_winter_ALL_REC_BWA.mat')
bwa_recNaN = [ALLdata(:,2), ALLdata(:,3)];
load('NN_winter_ALL_REC_BWA.mat')
bwa_recNaN = [bwa_recNaN; ALLdata(:,2),ALLdata(:,3)];
bwa_rec = bwa_recNaN(isnan(bwa_recNaN(:,1))==0 & isnan(bwa_recNaN(:,...
    2))==0 & bwa_recNaN(:,1)< 85,:);

lim_max = floor(max(bwa_rec(:,1)))+5;
x = 0:5:lim_max;  % Here we set the range of the intervals to 5 m^2
freq = zeros(1,length(x));

rec_mean_all = [];

for jj = 1:length(x)-1
    bwa_freq = 0;
    rec_freq = 0;
    for j = 1:length(bwa_rec(:,1))
               
        if bwa_rec(j,1) > x(jj) && bwa_rec(j,1) < x(jj+1)
            freq(jj) = freq(jj) + 1;
            rec_freq = rec_freq + bwa_rec(j,2);
        end     
    end
    if freq (jj) == 0
        rec_mean_all = [rec_mean_all; NaN];
    else
        rec_mean_all = [rec_mean_all; rec_freq/freq(jj)];
    end
end

x(1) = 1; % To avoid the -inf that arises from log(0)

figure(141)
subplot(1,2,1)
hold on
grid on
title('Mean recession (intervals 5 m^{2}) vs BWA')
plot(x(1:end-1),rec_mean_all,'or')
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ','Interpreter','LaTeX','FontSize',20)
ylabel('Mean recession ','Interpreter','LaTeX','FontSize',20)
subplot(1,2,2)
hold on
grid on
title('log(mean recession) vs log(BWA)')
plot(log(x(1:end-1)),log(rec_mean_all),'or')
set(gca,'FontName','times','FontSize',16)
xlabel('BWA ','Interpreter','LaTeX','FontSize',20)
ylabel('Mean recession','Interpreter','LaTeX','FontSize',20)

figure(142)
hold on
grid on
title('loglog plot (mean recession rate based on 5 m^{2} BWA intervals)')
p1 = plot(log(x(1:end-1)),log(rec_mean_all),'or','MarkerSize',7.6);
plot(log(x(1:end-1)),log(rec_mean_all),'or','MarkerSize',7.5)
set(gca,'FontName','times','FontSize',16)
xlabel('BWA','Interpreter','LaTeX','FontSize',20)
ylabel('Mean recession rate','Interpreter','LaTeX','FontSize',20)

% Fitting the trend
xp = log(x(5:end-1)); % We fit using the value where we see a trend change
yp = log(rec_mean_all(5:end))';
p2 = plot(xp,yp,'xb','MarkerSize',7.6);
pol = polyfit(xp,yp,1);
yp2 = polyval(pol,xp);
plot(xp,yp2,'b','LineWidth',2.1)
text(0.1,-2,'The change in trend correspond to the first limit of the hierarchical cluster', 'FontSize',16)
text(3.8,0.7,['Slope: ', num2str(round(pol(1),2))],'FontSize',16)
text(3.8,0.5,['AxisY-cut: ', num2str(round(pol(2),1))],'FontSize',16)
legend([p1 p2],{'All data','Data used for fitting'},'Location','southwest','FontSize',20)

% The end
