%{ 
    Script develovep to obtain the CCO coastal profile data of Suffolk and
    calculate the annual recession rate (rec) and the beach wegde area (BWA)
    using the detrended method to obtain the top and toe cliff and
    calculating the BWA using the area below the curve. After that the
    decadal scale relationship and the probability distribution between
    BWA and rec are calculated. In the script we also repeat the analysis
    for the previous work results (Lee 2008) for validated the methodology.

    This script was completed on October 25, 2019 (by P.M.L. Granada)
%}

%% 1. We extract those profiles that contain the Reg_ID identifiers we are
% 	  interested in and add the corresponding date.

clc, clear
close all

% Names of the Reg_IDs that Lee used, the unprotected sites
prfID = {'3c00071', '3c00088', '3c00176', '3c00204', '3c00220',...
         '3c00245', '3c00263', '3c00280', '3c00295'};

% Loading .txt data
G = dir('*.txt');
G = struct2cell(G);
G = G(1,:)';
DAT = [];
TEX = [];

% We go through all the files comparing the Reg_IDs and filling in the 
% variables for numeric data and for text data.
for ii = 1:length(G)
    
    fprintf('Processing file %d of %d - %s\n',ii,length(G),G{ii})
    fid = fopen(G{ii}); 
    prf = textscan(fid,'%f %f %f %f %s %s %s',...
    'Delimiter','\t','CollectOutput',1,'Headerlines',1);
    II = zeros(size(prf{1,2},1),length(prfID));
    STR = (prf{1,2}(:,3));
    
    for jj = 1:length(prfID)
        
        I = (strcmp(STR,prfID{jj}));
        II(:,jj) = I;
    end
    
    II = sum(II,2); 
    if sum(II) > 0
        II = logical(II);
        DAT = [DAT; [(prf{1,1}(II,:)) datenum(repmat({G{ii}(10:17)},...
            sum(II),1), 'yyyymmdd')]];
        TEX = [TEX; [prf{1,2}(II,:) repmat({G{ii}(10:17)},sum(II),1)]];
    end
    fclose(fid);   
end

% We save all the files we are interested in according to their type (data
% or text), in .mat format, separated by their identifiers

for jj = 1:length(prfID)
    
    fprintf('Saving file %d of %d - %s\n',jj,length(prfID),prfID{jj})
    I = (strcmp(TEX(:,3),prfID{jj}));
    dat = DAT(I,:);
    tex = TEX(I,:);
    save([prfID{jj},'.mat'],'dat','tex')
    
end

%% 2. Plotting all the profiles of a selected location in the same Figure
clear, clc
close all

load 3c00088

figure(100)
hold on
grid on
colorbar('Ticks',[0.02,0.248,0.515,0.75,0.9809],'TickLabels',{'1993',...
    '1999','2006','2012','2018'})
xlabel('Chainage (m)')
ylabel('Elevation (m)')

% To plot by date we get only one value per profile
yr = unique(tex(:,4));

clr = colormap(jet(length(yr)));

% We make a loop to represent all the profiles in the same Figure
for ii = 1 : length(yr)
    
    I = (strcmp(tex(:,4),yr{ii}));
    plot(dat(I,4),dat(I,3),'Color',clr(ii,:))
    drawnow
    
end

%% 3. We screen the profiles that are duplicated

clc, clear
close all

G = dir('3c00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id);

    yr = unique(dat(:,5));

    DAT = [];
    TEX = [];
    % We use the date and the chainage to screen the duplicated
    for ii = 1 : length(yr)

        i0 = find(dat(:,5) == yr(ii));
        x = dat(i0,4);
        [~, ia, ic] = unique(x);

        DAT = [DAT; dat(i0(ia),:)];
        TEX = [TEX; tex(i0(ia),:)];
        
    end
    
    dat = DAT;
    tex = TEX;
    
    fprintf('Saving file %d of %d - %s\n',jj,length(G),G{jj}(1:7))
    save(id,'dat','tex')
end

%% 4. We extract Lee profiles, winter profiles and years until 2003

clear, clc

G = dir('3c00*');
G = struct2cell(G);
G = G(1,:)';

for jj = 1:length(G)
    
    id = G{jj};
    load(id);

    DAT = [];
    TEX = [];
    a = tex(:,4);

    for ii = 1 : length(a)

        b = str2double(a{ii}(5:6));  % To be the winter profile
        c = str2double(a{ii}(1:4));  % To be the year use by Lee

        if (b < 5) && (c < 2004)
            DAT = [DAT; dat(ii,:)];
            TEX = [TEX; tex(ii,:)];   
        end
    end
    dat = DAT;
    tex = TEX;
    
    fprintf('Saving new Lee file %d of %d - %s\n',jj,length(G),G{jj}(1:7))
    save(['Lee', id],'dat','tex')
    
end

%% 5.1 Script to extract the cliff top using the detrended method and
% calculate the recession rate for all the profiles.
% 5.2 Script to extract the cliff toe using the detrended method and
% calculate the BWA for all the profiles, using the method that involve the
% local min and ckecking that the BWA is under a maximum value (bwa_max).
% The two scripts could be join to avoid the repetition of certain loops.

clear

% Names of the Reg_IDs that Lee used, the unprotected sites
prfID = {'Lee3c00071', 'Lee3c00088', 'Lee3c00176', 'Lee3c00204',...
    'Lee3c00220','Lee3c00245','Lee3c00263','Lee3c00280','Lee3c00295'};

J = dir('*_bwa_rec.mat');
J = struct2cell(J);
J = J(1,:)';
% We create one MHWS data based on the two values that Lee suplied
mhws = [1.0;1.0;1.0;1.0;1.0;1.0;1.0;1.0;1.0;];
% mhws = [0.97,0.97,0.94,0.93,0.93,0.92,0.92,0.90,0.90]; % Updated values
bwa_max = 80.0;  % Based on the Lee's results

% Variables that we are going to save
ALLdata = [];
ALLnames = [];
MEAN = [];
rec_tot = [];

for jj = 1:length(prfID)
    
    id = prfID{jj};
    load(id);
    
    yr = unique(dat(:,5));
    
    % 5.1. RECESSION RATE
    
    TOP_X = [];
    TOP_Z = [];
    
    for ii = 1 : length(yr)
        
        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);
        
        x_interp = x(1):0.01:x(end);
        z_interp = interp1(x,z,x_interp,'linear');
        
        % Detrending
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1-z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);
        
        % We calculate the max that correspond to the top and we use the
        % interpolate points to obtain it. For be rigorous, we should
        % search the values of the profiles that correspond to those points,
        % but it's not neccesary because the interpolation is very accurate
        % (+/- 0.01)
        
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        top_z = z_interp(find(max(z_detrend)==z_detrend,1));
        
        % Below we calculate the top with more accuracy using the previous
        % top for the interpolation and the toe (obtained as the first
        % minimun after the cliff) as the limit
        
        x_interp_top2 = top_x:0.01:x(end);
        z_interp_top2 = interp1(x,z,x_interp_top2,'linear');
        z0 = z_interp_top2(end);
        z1 = z_interp_top2(1);
        x0 = x_interp_top2(end);
        x1 = x_interp_top2(1);
        a = (z1-z0)/(x1-x0);
        z_detrend_top2 = z_interp_top2 - (a*x_interp_top2);
        
        TF1 = islocalmin(z_detrend_top2);
        
        toe_z = z_interp_top2(TF1);
        % Condition to extract the first min in the case that are several
        if length(toe_z) > 1
            toe_z = toe_z(1);
        end
        
        TF2 = isempty(toe_z);
        if TF2 == 0
            pos_toe = find(z_interp_top2 == toe_z);
            top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
            top_z = z_interp_top2(find(max(z_detrend_top2(1:pos_toe))==z_detrend_top2,1));
        end
        
        % Condition for the incomplete profiles
        if top_z < 3
            top_z = NaN;
            top_x = NaN;
        end
        
        TOP_X = [TOP_X; top_x];
        TOP_Z = [TOP_Z; top_z];
        
    end
    top_xz = [TOP_X,TOP_Z];
    
    rec = zeros([length(top_xz) 1]);
    rec(1) = 0.0;
    for ii = 2:length(top_xz)
        if top_xz(ii,1)*top_xz(ii-1,1) <= 0
            rec(ii) = abs(top_xz(ii,1)) + abs(top_xz(ii-1,1));
        else
            rec(ii) = abs(abs(top_xz(ii,1)) - abs(top_xz(ii-1,1)));
        end
    end
    
    % 5.2 BEACH WEDGE AREA
    
    BWA = [];
    
    for ii = 1 : length(yr)
        
        % First we calculate top and toe cliff for each profile as earlier
        x = dat(dat(:,5) == yr(ii),4);
        z = dat(dat(:,5) == yr(ii),3);
        
        x_interp = x(1):0.01:x(end);
        z_interp = interp1(x,z,x_interp,'linear');
        
        % Detrending
        z0 = z_interp(end);
        z1 = z_interp(1);
        x0 = x_interp(end);
        x1 = x_interp(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend = z_interp - (a*x_interp);
        
        % We calculate the min and the max that correspond to toe and top.
        
        top_x = x_interp(find(max(z_detrend)==z_detrend,1));
        top_z = z_interp(find(max(z_detrend)==z_detrend,1));
        
        % We interpolate again and we repeat the detrending...
        
        x_interp_top = top_x:0.01:x(end);
        z_interp_top = interp1(x,z,x_interp_top,'linear');
        z0 = z_interp_top(end);
        z1 = z_interp_top(1);
        x0 = x_interp_top(end);
        x1 = x_interp_top(1);
        a = (z1 - z0)/(x1-x0);
        z_detrend_top = z_interp_top - (a*x_interp_top);
        
        TF_top = islocalmin(z_detrend_top);
        
        toe_x = x_interp_top(TF_top);
        toe_z = z_interp_top(TF_top);
        
        if length(toe_x) > 1  % To extract the first minimun
            toe_x = toe_x(1);
            toe_z = toe_z(1);
        end
        
        % We calculate again the top using only the values until the toe
        
        if isempty(toe_z) == 0
            pos_toe = find(z_interp_top == toe_z);
            top_x = x_interp_top(find(max(z_detrend_top(1:pos_toe))==z_detrend_top,1));
            top_z = z_interp_top(find(max(z_detrend_top(1:pos_toe))==z_detrend_top,1));
        end
        
        if top_z < 3  % Condition for the incomplete profiles
            top_z = NaN;
            top_x = NaN;
            toe_x = NaN;
            toe_z = NaN;
        end
        
        % First calculation of BWA
        
        xz_cut = find(z_interp >= mhws(jj),1,'last');
        z_interp = z_interp - mhws(jj);
        xz_toe = find(x_interp >= toe_x,1,'first');
        bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
        
        % We check if we have a TOE. If we don't then bwa = NaN. This can
        % happen when the profile is not complete
        if isempty(xz_toe) == 1
            bwa = NaN;
        end
        % If the bwa obtained is bigger that bwa_max we repeated the
        % calculation of the toe, as the second local minimun
        if bwa > bwa_max
            
            % We interpolate again because the top may has changed
            x_interp_top2 = top_x:0.01:x(end);
            z_interp_top2 = interp1(x,z,x_interp_top2,'linear');
            z0 = z_interp_top2(end);
            z1 = z_interp_top2(1);
            x0 = x_interp_top2(end);
            x1 = x_interp_top2(1);
            a = (z1 - z0)/(x1-x0);
            z_detrend_top2 = z_interp_top2 - (a*x_interp_top2);
            
            TF_top2 = islocalmin(z_detrend_top2);
            
            toe_x = x_interp_top2(TF_top2);
            toe_z = z_interp_top2(TF_top2);
            
            if length(toe_x) > 1   % Condition to extract the second min
                toe_x = toe_x(2);
                toe_z = toe_z(2);
            end
            % We calculate again the top using only the values until the toe
            
            if isempty(toe_z) == 0
                pos_toe = find(z_interp_top2 == toe_z);
                top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe)) == z_detrend_top2,1));
            end
            
            % Second calculation of BWA
            
            xz_toe = find(x_interp >= toe_x,1,'first');
            bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
            
            if isempty(xz_toe) == 1
                bwa = NaN;
            end
            
            if bwa > bwa_max  % Toe calculation if bwa > bwa_max still
                
                toe_x = x_interp_top2(TF_top2);
                toe_z = z_interp_top2(TF_top2);
                
                if length(toe_x) > 2   % Condition to extract the third min
                    toe_x = toe_x(3);
                    toe_z = toe_z(3);
                else                   % If exits
                    toe_x = toe_x(2);
                    toe_z = toe_z(2);
                end
                
                % We calculate again the top using only the values until the toe
                
                if isempty(toe_z) == 0
                    pos_toe = find(z_interp_top2 == toe_z);
                    top_x = x_interp_top2(find(max(z_detrend_top2(1:pos_toe)) == z_detrend_top2,1));
                end
                
                % Third calculation of BWA
                
                xz_toe = find(x_interp >= toe_x,1,'first');
                bwa = trapz(x_interp(xz_toe:xz_cut),z_interp(xz_toe:xz_cut));
                
                if isempty(xz_toe) == 1
                    bwa = NaN;
                end
                
            end
        end
        
        BWA = [BWA; bwa];
    end
       
    % We save all the BWA, REC in one unique table, with the corresponding
    % date and we use another table for save the corresponding survey unit.
    % In this way, later it will be easier to find the outliers
    date = str2num(datestr(yr,'yyyy'));
    unit = tex(1,3);
    % We load the results of Lee because we are going to save all together
    load(J{jj});
    Lee = eval(J{jj}(1:(end-4)));
    
    % Here we calculate the mean value of BWA using the same year of REC
    BWA_mean = [];
    BWA_mean = [BWA_mean; BWA(1)];
    for k = 1:length(BWA)-1
        
        if isnan(BWA(k))
            BWA_mean = [BWA_mean; BWA(k)];
        else
            BWA_mean = [BWA_mean; nanmean([BWA(k),BWA(k+1)])];
        end    
    end
    
    % We calculate the mean value for each monitoring site before populate
    % with Nan
    Allmean = [mean(BWA,'omitnan') mean(rec,'omitnan') mean(Lee(:,2)) mean(Lee(:,3))];
    MEAN = [MEAN; Allmean];
    
    % We calculate the total recession for the 10 years
    rec_tot = [rec_tot; sum(rec,'omitnan')];
    
    % We create unique time vector and populate with NaN the missing years
    vt = unique([date; Lee(:,1)]);
    for n=1:length(vt)
        iOurs = find(date==vt(n));
        iLee = find(Lee(:,1)==vt(n));
        
        if isempty(iOurs)
            dumOurs = NaN(1,3);
            dumOurs(1,1) = vt(n);
        else
            dumOurs = [date(iOurs) BWA_mean(iOurs) rec(iOurs)];
        end
        
        if isempty(iLee)
            dumLee = NaN(1,3);
        else
            dumLee = Lee(iLee,:);
        end
        
        AllData(n,:) = [dumOurs dumLee];
        Allnames(n,:) = unit{1};
    end
    
    ALLdata = [ALLdata; AllData];
    ALLnames = [ALLnames; Allnames];
    
end

% We calculate the errors between our and Lee results
dif_bwa = ALLdata(:,2)- ALLdata(:,5);
dif_rec = ALLdata(:,3)- ALLdata(:,6);

save(['S_Lee_ALL_REC_BWA', '.mat'],'ALLdata','ALLnames','MEAN','rec_tot','dif_bwa','dif_rec')
fprintf(' S_Lee_ALL_REC_BWA calculated and saved ')

%% 6. Scatter plots for Recession and BWA and Decadal Scale Relationships

clc,clear

load ('S_Lee_ALL_REC_BWA.mat')

% Ouliers for BWA for one value of MHWS
outliers_bwa = [68.16,40.91; 62.31,25.49; 34.56,4.943;...
    27.96,5.005; 23.24,2.397; 34.19,57.27; 25.61,52.83]; % One MHWS

% load ('S_Lee2017_ALL_REC_BWA.mat') % Updated MHWS
% outliers_bwa = [73.27,40.91; 67.37,25.49; 36.76,4.943;...
%     29.46, 5.055; 24.32,2.397; 36.67,57.27;28.27,52.83];  % Updated MHWS

error_bwa = 2*nanstd(dif_bwa);
error_rec = 2*nanstd(dif_rec);

green = 1/255*[3,188,33];
red = 1/255*[235,6,3];
blue = 1/255*[2,6,200];

% These are the outliers point for recession rate
outliers_rec = [8.86,0.06789;7.61,1.848;13.64,6.554;7.96,15.15;0,9.717];

figure(88)
subplot(2,2,2)
hold on
grid on
title({'\bf Suffolk cliffs';'\bf (b) Recession rate \boldmath$ (m/yr)$'},...
    'Interpreter','LaTeX');
set(gca,'FontName','times','FontSize',15)
ylabel('Lee','Interpreter','LaTeX','FontSize',16)
xlabel('Ours','Interpreter','LaTeX','FontSize',16)
plot(ALLdata(:,3),ALLdata(:,6),'o','MarkerSize',5.9,'MarkerEdgeColor',green)
plot(outliers_rec(:,1),outliers_rec(:,2),'o','MarkerSize',6,...
    'MarkerEdgeColor',blue)
plot(0:0.1:(max(ALLdata(:,3)+5)),0:0.1:(max(ALLdata(:,3))+5),'k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,3)-1.5)))+error_rec,(0:0.1:(max(ALLdata(:,3))-1.5)),'--k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,3)+1)))-error_rec,(0:0.1:(max(ALLdata(:,3))+1)),'--k',...
    'LineWidth',0.75)
xlim([0 20])
ylim([0 20])

subplot(2,2,4)
hold on
grid on
plot(ALLdata(:,2),ALLdata(:,5),'o','MarkerSize',5.9,'MarkerEdgeColor',green)
plot(outliers_bwa(:,1),outliers_bwa(:,2),'o','MarkerSize',6,...
    'MarkerEdgeColor',red)
plot(0:0.1:(max(ALLdata(:,2))+22),0:0.1:(max(ALLdata(:,2))+22),'k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,2))))+error_bwa,0:0.1:(max(ALLdata(:,2))),'--k',...
    'LineWidth',0.75)
plot((0:0.1:(max(ALLdata(:,2))+22))-error_bwa,0:0.1:(max(ALLdata(:,2))+22),'--k',...
    'LineWidth',0.75)
xlim([0 80])
ylim([0 80])
set(gca,'FontName','times','FontSize',15)
title('\bf (d) Beach Wedge Area \boldmath$ \: (m^{2})$','Interpreter','LaTeX')
ylabel('Lee','Interpreter','LaTeX','FontSize',16)
xlabel('Ours','Interpreter','LaTeX','FontSize',16)

% Decadal Scale Relationships plots
figure(67)
hold on
grid on
title('Decadal Scale Relationship YEARLY data individual SDMS')
xlabel('BWA (m^2)')
ylabel('Recession rate (m/year)')
plot(ALLdata(:,2),ALLdata(:,3),'ob')
plot(ALLdata(:,5),ALLdata(:,6),'or')
legend('Ours','Lee')

figure(68)
hold on
grid on
title('Decadal Scale Relationship MEAN value individual SDMS')
xlabel('BWA (m^2)')
ylabel('Recession rate (m/year)')
plot(MEAN(:,1),MEAN(:,2),'ob')
plot(MEAN(:,3),MEAN(:,4),'or')
legend('Ours','Lee')

% Histograms for errors

std_bwa_S = round(nanstd(dif_bwa),2);
std_rec_S = round(nanstd(dif_rec),2);
mean_bwa_S = round(nanmean(dif_bwa),2);
mean_rec_S = round(nanmean(dif_rec),2);

figure(33)
subplot(2,2,2)
h1 = histogram(dif_rec);
hold on
h1.FaceColor = [0 0.5 0.5];
h1.EdgeColor = 'k';
set(gca,'FontName','times','FontSize',17)
title('\bf Suffolk cliffs','FontSize',18)
xlabel('Recession rate error ($m$/year)','Interpreter','LaTeX','FontSize',18)
ylabel('Count','Interpreter','LaTeX','FontSize',18)
text(4.5,45,['mean: ', num2str(mean_rec_S)],'FontSize',16)
text(4.5,40,['std: ', num2str(std_rec_S)],'FontSize',16)
rectangle('Position',[4.1 35 5.1 15],'Curvature',0.1)
xlim([-11,11])
subplot(2,2,4)
h1 = histogram(dif_bwa);
h1.FaceColor = [0 0.5 0.5];
h1.EdgeColor = 'k';
hold on
xlabel('BWA error ($m^2$)','Interpreter','LaTeX','FontSize',18)
ylabel('Count','Interpreter','LaTeX','FontSize',18)
text(17,30.5,['mean: ', num2str(mean_bwa_S)],'FontSize',16)
text(17,27,['std: ', num2str(std_bwa_S)],'FontSize',16)
rectangle('Position',[15.6 23.5 20 10],'Curvature',0.1)
set(gca,'FontName','times','FontSize',17)
xlim([-45,45])

%% 7. Probability distributions

close all
clear, clc

load('S_Lee_ALL_REC_BWA')

green = 1/255*[3,188,33];
red = 1/255*[235,6,3];

% We separate into different BWA ranges ours and Lee's data

lim1 = 15;
lim2 = 25;

zone1_ours = [];
zone2_ours = [];
zone3_ours = [];
zone1_Lee = [];
zone2_Lee = [];
zone3_Lee = [];

for ii = 1:length(ALLdata(:,2))
   
    if ALLdata(ii,2) < lim1        
        zone1_ours = [zone1_ours; ALLdata(ii,2) ALLdata(ii,3)];     
    elseif ALLdata(ii,2) > lim1 && ALLdata(ii,2) < lim2
        zone2_ours = [zone2_ours; ALLdata(ii,2) ALLdata(ii,3)];    
    else
        zone3_ours = [zone3_ours; ALLdata(ii,2) ALLdata(ii,3)];      
    end
    
    if ALLdata(ii,5) < lim1        
        zone1_Lee = [zone1_Lee; ALLdata(ii,5) ALLdata(ii,6)];       
    elseif ALLdata(ii,5) >= lim1 && ALLdata(ii,5) <= lim2
        zone2_Lee = [zone2_Lee; ALLdata(ii,5) ALLdata(ii,6)];       
    else
        zone3_Lee = [zone3_Lee; ALLdata(ii,5) ALLdata(ii,6)];        
    end
    
end

% We count the data that are found in intervals of 1 m/yr of the recession 
% rate and plot for all the data and the different zones

%% All data
lim_max = floor(max(ALLdata(:,6)))+1;
x = 0:1:lim_max;  % Here we can change the range of the intervals
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(ALLdata(:,6))
               
        if ALLdata(j,3) > x(jj) && ALLdata(j,3) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    
    for j = 1:length(ALLdata(:,6))    
        if ALLdata(j,6) > x(jj) && ALLdata(j,6) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end       
    end      
end

figure(53)
hold on
grid on
title('ALL')
bar(x,y_ours/sum(y_ours),'FaceColor', green)
xlabel('Recession (m)')
ylabel('Probability')
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
xlim([-0.5 20])
ylim([0 1])
legend('Ours','Lee')

%% ZONE 1   BWA > 15 m^2

lim_max = floor(max(zone1_Lee(:,2)))+1;
x = 0:1:lim_max;
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone1_ours(:,2))
               
        if zone1_ours(j,2) > x(jj) && zone1_ours(j,2) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    for j = 1:length(zone1_Lee(:,2))
        
        if zone1_Lee(j,2) > x(jj) && zone1_Lee(j,2) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end      
    end     
end

figure(99)
subplot(3,2,2)
hold on
grid on
bar(x,y_ours/sum(y_ours),'FaceColor', green)
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
set(gca,'FontName','times','FontSize',11)
title({'\bf Suffolk cliffs'; '\bf BWA \boldmath$< \: 15 \: m^{2}$'},...
    'Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',10)
xlim([-0.5 20])
ylim([0 1])

%% ZONE 2	BWA 15-25 m^2

lim_max = floor(max(zone2_Lee(:,2)))+1;
x = 0:1:lim_max;
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone2_ours(:,2))
               
        if zone2_ours(j,2) > x(jj) && zone2_ours(j,2) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    for j = 1:length(zone2_Lee(:,2))
        
        if zone2_Lee(j,2) > x(jj) && zone2_Lee(j,2) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end       
    end     
end

figure(99)
subplot(3,2,4)
hold on
grid on
bar(x,y_ours/sum(y_ours),'FaceColor', green)
set(gca,'FontName','times','FontSize',11)
title('\bf BWA 15 - 25 \boldmath$m^2$','Interpreter','LaTeX')
ylabel('Probability','Interpreter','LaTeX','FontSize',10)
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
legend('Ours','Lee')
xlim([-0.5 20])
ylim([0 1])

%% ZONE 3	BWA > 25 m^2

lim_max = floor(max(zone3_Lee(:,2)))+1;
x = 0:1:lim_max;
y_ours = zeros(1,length(x));
y_Lee = zeros(1,length(x));

for jj = 1:length(x)-1
    
    for j = 1:length(zone3_ours(:,2))
               
        if zone3_ours(j,2) > x(jj) && zone3_ours(j,2) < x(jj+1)
            y_ours(jj) = y_ours(jj) + 1;
        end
    end
    for j = 1:length(zone3_Lee(:,2))
        
        if zone3_Lee(j,2) > x(jj) && zone3_Lee(j,2) < x(jj+1)
            y_Lee(jj) = y_Lee(jj) + 1;
        end     
    end     
end

figure(99)
subplot(3,2,6)
hold on
grid on
bar(x,y_ours/sum(y_ours),'FaceColor', green)
set(gca,'FontName','times','FontSize',11)
title('\bf BWA \boldmath$> \: 25 \: m^{2}$','Interpreter','LaTeX')
xlabel('Recession rate $(m/yr)$','Interpreter','LaTeX','FontSize',12)
ylabel('Probability','Interpreter','LaTeX','FontSize',11.5)
bar(x,y_Lee/sum(y_Lee),0.3,'FaceColor', red)
xlim([-0.5 20])
ylim([0 1])
